@@ -31,7 +31,7 @@ Exceptions:
   * msgfmt.PoSyntaxError if the po file has syntax errors
 
 """
-from __future__ import print_function
+
 
 import struct
 import array
@@ -64,10 +64,7 @@ class Msgfmt:
         output = []
         if isinstance(self.po, str):
             # self.read() expects an iterable of "str" lines
-            if pycompat.ispy3:
-                output = open(self.po, 'r', encoding='utf-8')
-            else:
-                output = open(self.po, 'r')
+            output = open(self.po, 'r', encoding='utf-8')
         elif isinstance(self.po, file):
             self.po.seek(0)
             self.openfile = True
@@ -125,10 +122,7 @@ class Msgfmt:
                              7*4,               # start of key index
                              7*4+len(keys)*8,   # start of value index
                              0, keystart)       # size and offset of hash table
-        if pycompat.ispy3:
-            output += array.array("i", offsets).tobytes()
-        else:
-            output += array.array("i", offsets).tostring()
+        output += array.array("i", offsets).tobytes()
         output += ids
         output += strs
         return output
