@@ -11,7 +11,7 @@
 TortoiseHg About dialog - PyQt4 version
 """
 
-from __future__ import absolute_import
+
 
 import sys
 
@@ -19,10 +19,10 @@ from .qtcore import (
     PYQT_VERSION_STR,
     QSettings,
     QSize,
-    QT_VERSION_STR,
     QTimer,
     Qt,
     pyqtSlot,
+    qVersion,
 )
 from .qtgui import (
     QDialog,
@@ -77,7 +77,7 @@ class AboutDialog(QDialog):
         self.copyright_lbl = QLabel()
         self.copyright_lbl.setAlignment(Qt.AlignmentFlag.AlignCenter)
         self.copyright_lbl.setText('\n'
-                + _('Copyright 2008-2022 Steve Borho and others'))
+                + _('Copyright 2008-2023 Steve Borho and others'))
         self.vbox.addWidget(self.copyright_lbl)
         self.courtesy_lbl = QLabel()
         self.courtesy_lbl.setAlignment(Qt.AlignmentFlag.AlignCenter)
@@ -143,7 +143,7 @@ class AboutDialog(QDialog):
         thgv = (_('version %s') % version.version())
         libv = (_('with Mercurial-%s, Python-%s, PyQt-%s, Qt-%s') %
                 (hglib.hgversion, make_version(sys.version_info[0:3]),
-              PYQT_VERSION_STR, QT_VERSION_STR))
+              PYQT_VERSION_STR, qVersion()))
         par = ('<p style=\" margin-top:0px; margin-bottom:6px;\">'
                 '<span style=\"font-size:%spt; font-weight:600;\">'
                 '%s</span></p>')
@@ -161,7 +161,7 @@ class AboutDialog(QDialog):
 
     def showLicense(self):
         ld = LicenseDialog(self)
-        ld.exec_()
+        ld.exec()
 
     def closeEvent(self, event):
         self._updatechecker.close()
