@@ -6,7 +6,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import os
 
@@ -214,7 +214,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
     def browse_clicked(self):
         # type: () -> None
         """Select the destination directory or file"""
-        dest = pycompat.unicode(self.dest_edit.text())
+        dest = self.dest_edit.text()
         if not os.path.exists(dest):
             dest = os.path.dirname(dest)
         select = self.get_selected_archive_type()
@@ -275,7 +275,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
             # type: (Text) -> Text
             l = ''
             for i in pycompat.xrange(self.rev_combo.count() - 1):
-                l += pycompat.unicode(self.rev_combo.itemText(i))
+                l += self.rev_combo.itemText(i)
             revs = [rev[0] for rev in l]
             revs.append(wdrev)
             if not self.prevtarget is None:
@@ -295,7 +295,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
             return path
         # pytype: enable=redundant-function-type-comment
 
-        text = pycompat.unicode(self.rev_combo.currentText())
+        text = self.rev_combo.currentText()
         if len(text) == 0:
             self.commandChanged.emit()
             return
@@ -308,7 +308,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
             except (error.RepoError, error.LookupError):
                 self.commandChanged.emit()
                 return
-        path = pycompat.unicode(self.dest_edit.text())
+        path = self.dest_edit.text()
         path = remove_ext(path)
         path = remove_rev(path)
         path = add_rev(path, text)
@@ -355,7 +355,7 @@ class ArchiveWidget(cmdui.AbstractCmdWidget):
         # type: () -> cmdcore.CmdSession
         # verify input
         type = self.get_selected_archive_type()['type']
-        dest = pycompat.unicode(self.dest_edit.text())
+        dest = self.dest_edit.text()
         if os.path.exists(dest):
             if type == 'files':
                 if os.path.isfile(dest):
