@@ -5,12 +5,6 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
-
-from mercurial import (
-    pycompat,
-)
-
 from .qtcore import (
     QSettings,
     QSize,
@@ -401,7 +395,7 @@ class BackoutPage(BasePage):
         # type: (Text) -> None
         if cmd == 'resolve':
             dlg = resolve.ResolveDialog(self._repoagent, self)
-            dlg.exec_()
+            dlg.exec()
             if self.field('autoadvance'):
                 self.tryAutoAdvance(True)
             self.completeChanged.emit()
@@ -511,7 +505,10 @@ class CommitPage(BasePage):
             if self.isComplete():
                 self.wizard().next()
         actionEnter = QAction('alt-enter', self)
-        actionEnter.setShortcuts([Qt.Modifier.CTRL+Qt.Key.Key_Return, Qt.Modifier.CTRL+Qt.Key.Key_Enter])
+        actionEnter.setShortcuts([
+            qtlib.keyCombinationValue(Qt.Modifier.CTRL | Qt.Key.Key_Return),
+            qtlib.keyCombinationValue(Qt.Modifier.CTRL | Qt.Key.Key_Enter),
+        ])
         actionEnter.triggered.connect(tryperform)
         self.addAction(actionEnter)
 
@@ -563,7 +560,7 @@ class CommitPage(BasePage):
         # type: (Text) -> None
         if cmd == 'view':
             dlg = status.StatusDialog(self._repoagent, [], {}, self)
-            dlg.exec_()
+            dlg.exec()
             self.refresh()
 
     def isComplete(self):
@@ -587,14 +584,14 @@ class CommitPage(BasePage):
         if self._parentbackout:
             self.setTitle(_('Backing out and committing...'))
             self.setSubTitle(_('Please wait while making backout.'))
-            message = pycompat.unicode(self.msgEntry.text())
+            message = self.msgEntry.text()
             cmdline = hglib.buildcmdargs('backout', self._backoutrev,
                                          verbose=True,
                                          message=message, user=user)
         else:
             self.setTitle(_('Committing...'))
             self.setSubTitle(_('Please wait while committing merged files.'))
-            message = pycompat.unicode(self.msgEntry.text())
+            message = self.msgEntry.text()
             cmdline = hglib.buildcmdargs('commit', verbose=True,
                                          message=message, user=user)
         commandlines = [cmdline]
