@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 from .qtcore import (
     Qt,
@@ -26,7 +26,6 @@ from .qtgui import (
 
 from mercurial import (
     error,
-    pycompat,
 )
 
 from ..util import hglib
@@ -161,19 +160,13 @@ class BisectDialog(QDialog):
             ctx = hglib.revsymbol(self.repo, hglib.fromunicode(changeid))
             return ctx.rev()
         except (error.LookupError, error.RepoLookupError) as e:
-            self._stbar.showMessage(hglib.tounicode(str(e)))
+            self._stbar.showMessage(hglib.exception_str(e))
         except error.Abort as e:
-            if e.hint:
-                err = _('%s (hint: %s)') % (hglib.tounicode(str(e)),
-                                            hglib.tounicode(e.hint))
-            else:
-                err = hglib.tounicode(str(e))
-            self._stbar.showMessage(err)
+            self._stbar.showMessage(hglib.exception_str(e, show_hint=True))
 
     @pyqtSlot()
     def _verifyGood(self):
-        self.goodrev = self._lookupRevision(
-                           pycompat.unicode(self._gle.text()).strip())
+        self.goodrev = self._lookupRevision(self._gle.text().strip())
         if self.goodrev is None:
             return
         self._gb.setEnabled(False)
@@ -184,8 +177,7 @@ class BisectDialog(QDialog):
 
     @pyqtSlot()
     def _verifyBad(self):
-        self.badrev = self._lookupRevision(
-                          pycompat.unicode(self._ble.text()).strip())
+        self.badrev = self._lookupRevision(self._ble.text().strip())
         if self.badrev is None:
             return
         self._ble.setEnabled(False)
@@ -199,9 +191,9 @@ class BisectDialog(QDialog):
         self._setSession(self._repoagent.runCommandSequence(cmds, self))
 
     @pyqtSlot(QAbstractButton)
-    def _markRevision(self, button):
+    def _markRevision(self, button: QAbstractButton) -> None:
         self._nextbuttons.setEnabled(False)
-        state = str(button.objectName())
+        state = button.objectName()
         cmds = []
         if self.discard_chk.isChecked():
             cmds.append(hglib.buildcmdargs('revert', all=True))
