@@ -5,10 +5,14 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import re
 
+from typing import (
+    List,
+)
+
 from .qtcore import (
     QPoint,
     Qt,
@@ -138,8 +142,8 @@ class BookmarkDialog(QDialog):
     def repo(self):
         return self._repoagent.rawRepo()
 
-    def _allBookmarks(self):
-        return pycompat.maplist(hglib.tounicode, self.repo._bookmarks)
+    def _allBookmarks(self) -> List[str]:
+        return hglib.to_unicode_list(self.repo._bookmarks)
 
     @pyqtSlot()
     def refresh(self):
@@ -209,7 +213,7 @@ class BookmarkDialog(QDialog):
 
     @pyqtSlot()
     def add_bookmark(self):
-        bookmark = pycompat.unicode(self.bookmarkCombo.currentText())
+        bookmark = self.bookmarkCombo.currentText()
         if bookmark in self._allBookmarks():
             self.set_status(_('A bookmark named "%s" already exists') %
                             bookmark, False)
@@ -223,7 +227,7 @@ class BookmarkDialog(QDialog):
 
     @pyqtSlot()
     def move_bookmark(self):
-        bookmark = pycompat.unicode(self.bookmarkCombo.currentText())
+        bookmark = self.bookmarkCombo.currentText()
         if bookmark not in self._allBookmarks():
             self.set_status(_('Bookmark named "%s" does not exist') %
                             bookmark, False)
@@ -237,7 +241,7 @@ class BookmarkDialog(QDialog):
 
     @pyqtSlot()
     def remove_bookmark(self):
-        bookmark = pycompat.unicode(self.bookmarkCombo.currentText())
+        bookmark = self.bookmarkCombo.currentText()
         if bookmark not in self._allBookmarks():
             self.set_status(_("Bookmark '%s' does not exist") % bookmark, False)
             return
@@ -247,12 +251,12 @@ class BookmarkDialog(QDialog):
 
     @pyqtSlot()
     def rename_bookmark(self):
-        name = pycompat.unicode(self.bookmarkCombo.currentText())
+        name = self.bookmarkCombo.currentText()
         if name not in self._allBookmarks():
             self.set_status(_("Bookmark '%s' does not exist") % name, False)
             return
 
-        newname = pycompat.unicode(self.newNameEdit.text())
+        newname = self.newNameEdit.text()
         if newname in self._allBookmarks():
             self.set_status(_('A bookmark named "%s" already exists') %
                             newname, False)
@@ -397,11 +401,11 @@ class SyncBookmarkDialog(QDialog):
         self._updateActions()
 
     def selectedOutgoingBookmarks(self):
-        return [pycompat.unicode(x.text())
+        return [x.text()
                 for x in self.outgoingList.selectedItems()]
 
     def selectedIncomingBookmarks(self):
-        return [pycompat.unicode(x.text())
+        return [x.text()
                 for x in self.incomingList.selectedItems()]
 
     @pyqtSlot()
