@@ -5,12 +5,6 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
-
-from mercurial import (
-    pycompat,
-)
-
 from .qtgui import (
     QComboBox,
     QDialog,
@@ -115,8 +109,7 @@ class BranchOpDialog(QDialog):
         '''
         if self.branchCombo.isEnabled():
             # branch name cannot start/end with whitespace (see dirstate._branch)
-            self.branchop = pycompat.unicode(
-                                self.branchCombo.currentText()).strip()
+            self.branchop = self.branchCombo.currentText().strip()
         elif self.closebranch.isChecked():
             self.branchop = False
         else:
