@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import, print_function
+
 
 import os
 import sys
@@ -13,10 +13,10 @@ import sys
 from .qtcore import (
     PYQT_VERSION_STR,
     QSettings,
-    QT_VERSION_STR,
     QTimer,
     Qt,
     pyqtSlot,
+    qVersion,
 )
 from .qtgui import (
     QApplication,
@@ -31,7 +31,9 @@ from .qtgui import (
 )
 
 from mercurial import (
+    encoding,
     extensions,
+    vfs as vfsmod,
 )
 from ..util import (
     hglib,
@@ -146,7 +148,7 @@ class BugReport(QDialog):
         elif os.name == 'posix':
             text += '** System: %s\n' % hglib.tounicode(' '.join(os.uname()))
         text += ('** Qt-%s PyQt-%s QScintilla-%s\n'
-                 % (QT_VERSION_STR, PYQT_VERSION_STR, QSCINTILLA_VERSION_STR))
+                 % (qVersion(), PYQT_VERSION_STR, QSCINTILLA_VERSION_STR))
         text += hglib.tounicode(opts.get('error', 'N/A'))
         text += '\n```'
         return text
@@ -181,7 +183,9 @@ class BugReport(QDialog):
                 with open(fname, 'wb') as fp:
                     fp.write(hglib.fromunicode(self.text))
         except EnvironmentError as e:
-            QMessageBox.critical(self, _('Error writing file'), str(e))
+            QMessageBox.critical(
+                self, _('Error writing file'), hglib.exception_str(e)
+            )
 
     def closeEvent(self, event):
         self._updatechecker.close()
@@ -247,10 +251,10 @@ class ExceptionMsgBox(QDialog):
         self.resize(desktopgeom.size() * 0.20)
 
     @pyqtSlot(str)
-    def _openlink(self, ref):
-        ref = str(ref)
+    def _openlink(self, ref: str) -> None:
         if ref == '#bugreport':
-            return BugReport(self._opts, self).exec_()
+            BugReport(self._opts, self).exec()
+            return
         if ref.startswith('#edit:'):
             fname, lineno = ref[6:].rsplit(':', 1)
             try:
@@ -258,8 +262,17 @@ class ExceptionMsgBox(QDialog):
                 # editor in order to repair your ui config file.
                 class FakeRepo(object):
                     def __init__(self):
-                        self.root = os.getcwd()
+                        self.root = encoding.getcwd()
                         self.ui = hglib.loadui()
+                        self.vfs = vfsmod.vfs(
+                            os.path.join(self.root, b'.hg'),
+                            expandpath=True,
+                            realpath=True
+                        )
+
+                    def wjoin(self, f: bytes, *insidef: bytes) -> bytes:
+                        return self.vfs.reljoin(self.root, f, *insidef)
+
                 fake = FakeRepo()
                 qtlib.editfiles(fake, [hglib.fromunicode(fname)], int(lineno),
                                 parent=self)
@@ -270,7 +283,7 @@ class ExceptionMsgBox(QDialog):
             errtext = ref[5:].split(' ')[0]
             sd = settings.SettingsDialog(configrepo=False, focus=errtext,
                                 parent=self, root=b'')
-            sd.exec_()
+            sd.exec()
 
 def run(ui, *pats, **opts):
     return BugReport(opts)
@@ -279,4 +292,4 @@ if __name__ == "__main__":
     app = QApplication(sys.argv)
     form = BugReport({'cmd':'cmd', 'error':'error'})
     form.show()
-    app.exec_()
+    app.exec()
