@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import os
 import re
@@ -156,7 +156,7 @@ class ChunksWidget(QWidget):
             for act in actionlist:
                 menu.addAction(self._actions[act])
             self.contextmenu = menu
-        self.contextmenu.exec_(self.filelist.viewport().mapToGlobal(point))
+        self.contextmenu.exec(self.filelist.viewport().mapToGlobal(point))
 
     def vdiff(self):
         filenames = self.getSelectedFiles()
@@ -165,7 +165,7 @@ class ChunksWidget(QWidget):
         opts = {'change':self.ctx.rev()}
         dlg = visdiff.visualdiff(self.repo.ui, self.repo, filenames, opts)
         if dlg:
-            dlg.exec_()
+            dlg.exec()
 
     def revertfile(self):
         filenames = [hglib.tounicode(f) for f in self.getSelectedFiles()]
@@ -175,7 +175,7 @@ class ChunksWidget(QWidget):
         if rev is None:
             rev = self.ctx.p1().rev()
         dlg = revert.RevertDialog(self._repoagent, filenames, rev, self)
-        dlg.exec_()
+        dlg.exec()
         dlg.deleteLater()
 
     def timerEvent(self, event):
@@ -230,7 +230,7 @@ class ChunksWidget(QWidget):
                 self.showMessage.emit(_('Patch failed to apply'))
         except (patch.PatchError, EnvironmentError) as err:
             ok = False
-            self.showMessage.emit(hglib.tounicode(str(err)))
+            self.showMessage.emit(hglib.exception_str(err))
         rejfilere = re.compile(br'\b%s\.rej\b' % re.escape(wfile))
         for line in ui.popbuffer().splitlines():
             if rejfilere.search(line):
@@ -240,7 +240,7 @@ class ChunksWidget(QWidget):
                                        parent=self):
                     dlg = rejects.RejectsDialog(repo.ui, repo.wjoin(wfile),
                                                 self)
-                    if dlg.exec_() == QDialog.DialogCode.Accepted:
+                    if dlg.exec() == QDialog.DialogCode.Accepted:
                         ok = True
                     break
         return ok
@@ -451,7 +451,7 @@ class ChunksWidget(QWidget):
                 return []
         else:
             buf = util.bytesio()
-            diffopts = patch.diffopts(repo.ui, {'git':True})
+            diffopts = patch.diffopts(repo.ui, {b'git':True})
             m = scmutil.matchfiles(repo, [wfile])
             for p in patch.diff(repo, ctx.p1().node(), None, match=m,
                                 opts=diffopts):
@@ -689,7 +689,7 @@ class DiffBrowser(QFrame):
                     self.sci.markerDelete(i, self.selcolor)
         self.updateSummary()
 
-    @pyqtSlot(int, int, Qt.KeyboardModifiers)
+    #@pyqtSlot(int, int, Qt.KeyboardModifier)
     def marginClicked(self, margin, line, modifiers):
         for chunk in self.curchunks[1:]:
             if line >= chunk.lrange[0] and line < chunk.lrange[1]:
