@@ -5,12 +5,6 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
-
-from mercurial import (
-    pycompat,
-)
-
 from .qtgui import (
     QSizePolicy,
     QLineEdit,
@@ -63,7 +57,7 @@ class CloseWidget(cmdui.AbstractCmdWidget):
         # automatic message
         msgset = i18n.keepgettext()._('Close %s branch')
         str_msg = msgset['str']
-        self.hg_commit.setText(pycompat.unicode(str_msg) %
+        self.hg_commit.setText(str_msg %
                                hglib.tounicode(self._repo[self._rev].branch()))
         form.addRow(_('Commit message:'), self.hg_commit)
 
