@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import weakref
 
@@ -127,8 +127,7 @@ class ThgStatusBar(QStatusBar):
         else:
             self.lbl.setStyleSheet('')
 
-    def setRepoBusy(self, root, busy):
-        root = pycompat.unicode(root)
+    def setRepoBusy(self, root: str, busy):
         if busy:
             self._busyrepos.add(root)
         else:
@@ -150,8 +149,7 @@ class ThgStatusBar(QStatusBar):
             self._removeProgress(key)
 
     @pyqtSlot(str)
-    def clearRepoProgress(self, root):
-        root = pycompat.unicode(root)
+    def clearRepoProgress(self, root: str):
         keys = [k for k in self.topics if k[0] == root]
         for key in keys:
             self._removeProgress(key)
@@ -165,7 +163,7 @@ class ThgStatusBar(QStatusBar):
 
     # TODO: migrate to setProgress() API
     @pyqtSlot(str, object, str, str, object)
-    def progress(self, topic, pos, item, unit, total, root=None):
+    def progress(self, topic: str, pos, item: str, unit: str, total, root=None):
         'Progress signal received from repowidget'
         # topic is current operation
         # pos is the current numeric position (revision, bytes)
@@ -188,8 +186,7 @@ class ThgStatusBar(QStatusBar):
         else:
             pm = self.topics[key]
         if total:
-            fmt = '%s / %s ' % (pycompat.unicode(pos),
-                                pycompat.unicode(total))
+            fmt = '%s / %s ' % (str(pos), str(total))
             if unit:
                 fmt += unit
             pm.status.setText(fmt)
@@ -197,7 +194,7 @@ class ThgStatusBar(QStatusBar):
         else:
             if item:
                 item = item[-30:]
-            pm.status.setText('%s %s' % (pycompat.unicode(pos), item))
+            pm.status.setText('%s %s' % (str(pos), item))
             pm.unknown()
 
     @pyqtSlot(cmdcore.ProgressMessage)
@@ -205,8 +202,8 @@ class ThgStatusBar(QStatusBar):
         self.progress(*progress)
 
     @pyqtSlot(str, cmdcore.ProgressMessage)
-    def setRepoProgress(self, root, progress):
-        self.progress(*(progress + (pycompat.unicode(root),)))
+    def setRepoProgress(self, root: str, progress):
+        self.progress(*(progress + (root,)))
 
 
 def updateStatusMessage(stbar, session):
@@ -254,13 +251,13 @@ class LogWidget(qscilib.ScintillaCompat):
             # because it's a *Background* marker.
 
     @pyqtSlot(str, str)
-    def appendLog(self, msg, label):
+    def appendLog(self, msg: str, label: str):
         """Append log text to the last line; scrolls down to there"""
         self.append(msg)
         self._setmarker(pycompat.xrange(self.lines()
-                                        - pycompat.unicode(msg).count('\n')
+                                        - msg.count('\n')
                                         - 1,
-                               self.lines() - 1), pycompat.unicode(label))
+                               self.lines() - 1), label)
         self.setCursorPosition(self.lines() - 1, 0)
 
     def _setmarker(self, lines, label):
@@ -281,7 +278,7 @@ class LogWidget(qscilib.ScintillaCompat):
         menu = self.createStandardContextMenu()
         menu.addSeparator()
         menu.addAction(_('Clea&r Log'), self.clearLog)
-        menu.exec_(event.globalPos())
+        menu.exec(event.globalPos())
         menu.setParent(None)
 
     def keyPressEvent(self, event):
@@ -306,10 +303,10 @@ class InteractiveUiHandler(cmdcore.UiHandler):
         if uiparent:
             self._uiparentref = weakref.ref(uiparent)
 
-    def setPrompt(self, text, mode, default=None):
-        self._prompttext = pycompat.unicode(text)
+    def setPrompt(self, text: str, mode, default: Optional[str]=None):
+        self._prompttext = text
         self._promptmode = mode
-        self._promptdefault = pycompat.unicode(default or '')
+        self._promptdefault = default if default else ''
 
     def getLineInput(self):
         mode = self._promptmode
@@ -343,7 +340,7 @@ class InteractiveUiHandler(cmdcore.UiHandler):
         # button to close prompt dialog with empty response (i.e. abort)
         dlg.addButton(QMessageBox.StandardButton.Abort)
         dlg.setEscapeButton(QMessageBox.StandardButton.Abort)
-        dlg.exec_()
+        dlg.exec()
         button = dlg.clickedButton()
         if button and dlg.buttonRole(button) == QMessageBox.ButtonRole.ActionRole:
             return button.response
@@ -543,7 +540,7 @@ class CmdControlDialog(QDialog):
     public methods/signals, or implement custom error handling.
 
     Unlike QDialog, the result code is set to the exit code of the last
-    command.  exec_() returns 0 on success.
+    command.  exec() returns 0 on success.
     """
 
     commandFinished = pyqtSignal(int)
@@ -697,7 +694,7 @@ class CmdSessionDialog(QDialog):
     """Dialog to monitor running Mercurial commands
 
     Unlike QDialog, the result code is set to the exit code of the last
-    command.  exec_() returns 0 on success.
+    command.  exec() returns 0 on success.
     """
 
     # this won't provide commandFinished signal because the client code
