@@ -5,12 +5,15 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import os
 import re
 import tempfile
 import time
+from typing import (
+    cast,
+)
 
 from .qsci import (
     QsciAPIs,
@@ -156,11 +159,10 @@ def mergecommitmessage(repo):
     elif wctx.p1().branch() == wctx.p2().branch():
         msgset = i18n.keepgettext()._('Merge')
         text = engmsg and msgset['id'] or msgset['str']
-        text = pycompat.unicode(text)
     else:
         msgset = i18n.keepgettext()._('Merge with %s')
         text = engmsg and msgset['id'] or msgset['str']
-        text = pycompat.unicode(text) % hglib.tounicode(wctx.p2().branch())
+        text = text % hglib.tounicode(wctx.p2().branch())
     return text
 
 def _getUserOptions(opts, optionlist):
@@ -325,9 +327,10 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
                     parameters = self.opts['bugtraqparameters']
                     linktext = self.bugtraq.get_link_text(parameters)
                 except Exception as e:
-                    tracker = self.opts['bugtraqplugin'].split(' ', 1)[1]
+                    # TODO: use TypedDict instead of casting?
+                    tracker = cast(str, self.opts['bugtraqplugin']).split(' ', 1)[1]
                     errormsg =  _('Failed to load issue tracker \'%s\': %s') \
-                                 % (tracker, hglib.tounicode(str(e)))
+                                 % (tracker, hglib.exception_str(e))
                     self.showIssues.setToolTip(errormsg)
                     qtlib.ErrorMsgBox(_('Issue Tracker'), errormsg,
                                       parent=self)
@@ -701,7 +704,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         if self.msgte.lexer() is None:
             # qsci will crash if None is passed to QsciAPIs constructor
             return
-        wfile = pycompat.unicode(wfile)
+
         self._apis = QsciAPIs(self.msgte.lexer())
         tokens = set()
         for e in self.stwidget.getChecked():
@@ -720,7 +723,6 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
             )
 
             try:
-                contents = pycompat.unicode(contents)
                 lexer = guess_lexer_for_filename(wfile, contents)
                 assert lexer is not None  # help pytype
 
@@ -779,7 +781,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         dlg.finished.connect(dlg.deleteLater)
         dlg.setWindowFlags(Qt.WindowType.Sheet)
         dlg.setWindowModality(Qt.WindowModality.WindowModal)
-        if dlg.exec_() == QDialog.DialogCode.Accepted:
+        if dlg.exec() == QDialog.DialogCode.Accepted:
             self.opts.update(dlg.outopts)
             self.refresh()
 
@@ -874,7 +876,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         if self.hasmqbutton:
             parent = _('Parent:')
             patchname = _('Patch name:')
-            text = pycompat.unicode(self.wdirinfo.revlabel.text())
+            text = self.wdirinfo.revlabel.text()
             cellend = '</td>'
             firstidx = text.find(cellend) + len(cellend)
             secondidx = text[firstidx:].rfind('</tr>')
@@ -890,7 +892,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         d = branchop.BranchOpDialog(self._repoagent, self.branchop, self)
         d.setWindowFlags(Qt.WindowType.Sheet)
         d.setWindowModality(Qt.WindowModality.WindowModal)
-        if d.exec_() == QDialog.DialogCode.Accepted:
+        if d.exec() == QDialog.DialogCode.Accepted:
             self.branchop = d.branchop
             if self.branchop is False:
                 if not self.getMessage(True).strip():
@@ -898,7 +900,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
                         'tortoisehg', 'engmsg')
                     msgset = i18n.keepgettext()._('Close %s branch')
                     text = engmsg and msgset['id'] or msgset['str']
-                    self.setMessage(pycompat.unicode(text) %
+                    self.setMessage(text %
                                     hglib.tounicode(self.repo[None].branch()))
             self.msgte.setFocus()
             self.refresh()
@@ -908,7 +910,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         d = topic.TopicDialog(self._repoagent, None, self)
         d.setWindowFlags(Qt.WindowType.Sheet)
         d.setWindowModality(Qt.WindowModality.WindowModal)
-        d.exec_()
+        d.exec()
         self.msgte.setFocus()
         self.refresh()
 
@@ -988,7 +990,7 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
         self.msgte.loadSettings(s, lpref+'msgte')
         self.stwidget.loadSettings(s, lpref+'status')
         self.msghistory = qtlib.readStringList(s, gpref + 'history-' + repoid)
-        self.msghistory = [pycompat.unicode(m) for m in self.msghistory if m]
+        self.msghistory = [m for m in self.msghistory if m]
         self.updateRecentMessages()
         self.userhist = qtlib.readStringList(s, gpref + 'userhist')
         self.userhist = [u for u in self.userhist if u]
@@ -1023,7 +1025,6 @@ class CommitWidget(QWidget, qtlib.TaskWidget):
 
     def addMessageToHistory(self, umsg):
         # type: (Text) -> None
-        umsg = pycompat.unicode(umsg)
         if umsg in self.msghistory:
             self.msghistory.remove(umsg)
         self.msghistory.insert(0, umsg)
@@ -1465,7 +1466,7 @@ class DetailsDialog(QDialog):
             wconfig.writefile(cfg, fn)
         except IOError as e:
             qtlib.WarningMsgBox(_('Unable to write configuration file'),
-                                hglib.tounicode(str(e)), parent=self)
+                                hglib.exception_str(e), parent=self)
 
     def savePushAfter(self):
         path = os.path.join(self.repo.root, b'.hg', b'hgrc')
@@ -1488,7 +1489,7 @@ class DetailsDialog(QDialog):
             wconfig.writefile(cfg, fn)
         except IOError as e:
             qtlib.WarningMsgBox(_('Unable to write configuration file'),
-                                hglib.tounicode(str(e)), parent=self)
+                                hglib.exception_str(e), parent=self)
 
     def saveAutoInc(self):
         path = os.path.join(self.repo.root, b'.hg', b'hgrc')
@@ -1511,7 +1512,7 @@ class DetailsDialog(QDialog):
             wconfig.writefile(cfg, fn)
         except IOError as e:
             qtlib.WarningMsgBox(_('Unable to write configuration file'),
-                                hglib.tounicode(str(e)), parent=self)
+                                hglib.exception_str(e), parent=self)
 
     def saveRecurseInSubrepos(self):
         path = os.path.join(self.repo.root, b'.hg', b'hgrc')
@@ -1534,7 +1535,7 @@ class DetailsDialog(QDialog):
             wconfig.writefile(cfg, fn)
         except IOError as e:
             qtlib.WarningMsgBox(_('Unable to write configuration file'),
-                                hglib.tounicode(str(e)), parent=self)
+                                hglib.exception_str(e), parent=self)
 
     def accept(self):
         outopts = {}  # type: Dict[Text, Text]
@@ -1544,11 +1545,7 @@ class DetailsDialog(QDialog):
             try:
                 dateutil.parsedate(date)
             except error.ParseError as e:
-                if e.hint:
-                    err = _('%s (hint: %s)') % (hglib.tounicode(str(e)),
-                                                hglib.tounicode(e.hint))
-                else:
-                    err = hglib.tounicode(str(e))
+                err = hglib.exception_str(e, show_hint=True)
                 qtlib.WarningMsgBox(_('Invalid date format'), err, parent=self)
                 return
             outopts['date'] = udate
@@ -1564,11 +1561,7 @@ class DetailsDialog(QDialog):
             try:
                 self.repo.ui.username()
             except error.Abort as e:
-                if e.hint:
-                    err = _('%s (hint: %s)') % (hglib.tounicode(str(e)),
-                                                hglib.tounicode(e.hint))
-                else:
-                    err = hglib.tounicode(str(e))
+                err = hglib.exception_str(e, show_hint=True)
                 qtlib.WarningMsgBox(_('No username configured'),
                                     err, parent=self)
                 return
@@ -1653,7 +1646,6 @@ class CommitDialog(QDialog):
 
     def linkActivated(self, link):
         # type: (Text) -> None
-        link = pycompat.unicode(link)
         if link.startswith('repo:'):
             self._subdialogs.open(link[len('repo:'):])
 
