@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 from .qtcore import (
     QSettings,
@@ -127,7 +127,7 @@ class CompressDialog(QDialog):
 
         dlg = commit.CommitDialog(self._repoagent, [], {}, self)
         dlg.finished.connect(dlg.deleteLater)
-        dlg.exec_()
+        dlg.exec()
         self._cmdcontrol.showStatusMessage(_('Compress is complete, old '
                                              'history untouched'))
         self.compressbtn.hide()
