@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import binascii
 import re
@@ -240,8 +240,8 @@ class SummaryInfo(object):
                 if cvt.startswith(b'svn:'):
                     result = cvt.split(b'/', 1)[-1]
                     if cvt != result:
-                        return pycompat.unicode(result, 'utf-8', 'replace')
-                    return pycompat.unicode(cvt.split(b'@')[-1], 'utf-8', 'replace')
+                        return str(result, 'utf-8', 'replace')
+                    return str(cvt.split(b'@')[-1], 'utf-8', 'replace')
                 else:
                     return None
             elif item == 'converted':
@@ -410,7 +410,7 @@ class SummaryBase(object):
             self.update_ctx()
 
     def update_ctx(self):
-        if isinstance(self.target, pycompat.unicode):
+        if isinstance(self.target, str):
             target = hglib.fromunicode(self.target)
         else:
             target = self.target
