@@ -1030,7 +1030,7 @@ class HookConfigDialog(CustomConfigDialog):
             'conflicts not resolved), <tt>$HG_ERROR=1</tt>.'),
     )
 
-    _rehookname: Pattern[str] = re.compile('^[^=\s]*$')
+    _rehookname: Pattern[str] = re.compile(r'^[^=\s]*$')
 
     def __init__(
         self,
