@@ -8,6 +8,10 @@
 
 
 import os
+from typing import (
+    Dict,
+    List,
+)
 
 from .qsci import (
     QsciScintilla,
@@ -323,7 +327,7 @@ class ConsoleWidget(QWidget, qtlib.TaskWidget):
         else:
             self._logwidget.flash()
 
-    def _commandComplete(self, cmdtype, cmdline):
+    def _commandComplete(self, cmdtype: str, cmdline: str) -> List[str]:
         from tortoisehg.hgqt import run
         matches = []
         cmd = cmdline.split()
@@ -334,12 +338,12 @@ class ConsoleWidget(QWidget, qtlib.TaskWidget):
         subcmd = ''
         if len(cmd) >= 2:
             subcmd = cmd[1].lower()
-        def findhgcmd(cmdstart):
+        def findhgcmd(cmdstart: str) -> Dict[str, str]:
             matchinfo = {}
             for cmdspec in cmdtable:
-                for cmdname in cmdspec.split('|'):
-                    if cmdname.startswith(cmdstart):
-                        matchinfo[cmdname] = cmdspec
+                for cmdname in cmdspec.split(b'|'):
+                    if cmdname.startswith(hglib.fromunicode(cmdstart)):
+                        matchinfo[hglib.tounicode(cmdname)] = hglib.tounicode(cmdspec)
             return matchinfo
         matchingcmds = findhgcmd(subcmd)
         if not matchingcmds:
@@ -349,28 +353,29 @@ class ConsoleWidget(QWidget, qtlib.TaskWidget):
             matches = [basecmdline % c for c in matchingcmds]
         else:
             scmdtype = list(matchingcmds)[0]
-            cmdspec = matchingcmds[scmdtype]
+            cmdspec = hglib.fromunicode(matchingcmds[scmdtype])
             opts = cmdtable[cmdspec][1]
-            def findcmdopt(cmdopt):
+            def findcmdopt(cmdopt: str) -> List[str]:
                 cmdopt = cmdopt.lower()
                 while cmdopt.startswith('-'):
                     cmdopt = cmdopt[1:]
                 matchingopts = []
                 for opt in opts:
-                    if opt[1].startswith(cmdopt):
-                        matchingopts.append(opt)
+                    uopt = hglib.tounicode(opt[1])
+                    if uopt.startswith(cmdopt):
+                        matchingopts.append(uopt)
                 return matchingopts
             basecmdline = '%s %s --%%s' % (cmdtype, scmdtype)
             if len(cmd) == 2:
                 matches = ['%s %s ' % (cmdtype, scmdtype)]
-                matches += [basecmdline % opt[1] for opt in opts]
+                matches += [basecmdline % hglib.tounicode(opt[1]) for opt in opts]
             else:
                 cmdopt = cmd[-1]
                 if cmdopt.startswith('-'):
                     # find the matching options
                     basecmdline = ' '.join(cmd[:-1]) + ' --%s'
                     cmdopts = findcmdopt(cmdopt)
-                    matches = [basecmdline % opt[1] for opt in cmdopts]
+                    matches = [basecmdline % opt for opt in cmdopts]
         return sorted(matches)
 
     @pyqtSlot(str)
