@@ -7,7 +7,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import os
 import re
@@ -396,7 +396,7 @@ class FilectxActions(QObject):
         repo = self._repoAgentFor(an_fd).rawRepo()
         dlg = visdiff.visualdiff(repo.ui, repo, filenames, opts)
         if dlg:
-            dlg.exec_()
+            dlg.exec()
 
     @actionSlot(_('&View at Revision'), 'view-at-revision', 'Shift+Ctrl+E',
                 _('View file as it appeared at this revision using the '
@@ -525,7 +525,7 @@ class FilectxActions(QObject):
             rev = repo[rev].p1().rev()
         dlg = revert.RevertDialog(repoagent, fileSelection, rev,
                                   parent=self._parentWidget())
-        dlg.exec_()
+        dlg.exec()
 
     @actionSlot(_('Open S&ubrepository'), 'thg-repository-open', None,
                 _('Open the selected subrepository'),
@@ -771,7 +771,7 @@ class WctxActions(FilectxActions):
         repoagent = self._repoAgentFor(srcfd)
         dlg = RenameDialog(repoagent, self._parentWidget(),
                            srcfd.canonicalFilePath(), iscopy=iscopy)
-        if dlg.exec_() == 0:
+        if dlg.exec() == 0:
             self._notifyChanges()
 
     @actionSlot(_('&Ignore...'), 'thg-ignore', None, '',
@@ -783,7 +783,7 @@ class WctxActions(FilectxActions):
         files = _lcanonpaths(fds)
         dlg = HgignoreDialog(repoagent, parent, *files)
         dlg.finished.connect(dlg.deleteLater)
-        dlg.exec_()
+        dlg.exec()
         self._notifyChanges()
 
     @actionSlot(_('Edit Re&jects'), None, None,
@@ -792,7 +792,7 @@ class WctxActions(FilectxActions):
     def editRejects(self, fds: List["FileData"]) -> None:
         lpath = hglib.fromunicode(fds[0].absoluteFilePath()[:-4])  # drop .rej
         dlg = rejects.RejectsDialog(self._ui, lpath, self._parentWidget())
-        if dlg.exec_():
+        if dlg.exec():
             self._notifyChanges()
 
     @actionSlot(_('De&tect Renames...'), 'thg-guess', None, '',
@@ -808,7 +808,7 @@ class WctxActions(FilectxActions):
         ret = [False]
         dlg.matchAccepted.connect(matched)
         dlg.finished.connect(dlg.deleteLater)
-        dlg.exec_()
+        dlg.exec()
         if ret[0]:
             self._notifyChanges()
 
