@@ -9,7 +9,6 @@ import os, posixpath
 
 from typing import (
     List,
-    NoReturn,
     Optional,
     Text,
     Tuple,
@@ -123,7 +122,7 @@ class _AbstractFileData(object):
         # new status is not known
         return self.__class__(self._ctx, pctx, self._wfile, rpath=self._rpath)
 
-    def load(self, changeselect: bool = False, force: bool = False) -> NoReturn:
+    def load(self, changeselect: bool = False, force: bool = False) -> None:
         # Note: changeselect may be set to True even if the underlying data
         # isn't chunk-selectable
         raise NotImplementedError
@@ -274,7 +273,7 @@ class FileData(_AbstractFileData):
         except _BadContent as e:
             self.error = errorprefix + e.args[0] + '\n\n' + forcedisplaymsg
         except (EnvironmentError, error.LookupError, error.Abort) as e:
-            self.error = errorprefix + hglib.tounicode(str(e))
+            self.error = errorprefix + hglib.exception_str(e)
 
     def _checkMaxDiff(
         self,
@@ -410,7 +409,8 @@ class FileData(_AbstractFileData):
             if os.path.getsize(absfile) > maxdiff:
                 self.error = mde
                 return
-            data = util.posixfile(absfile, b'rb').read()
+            with util.posixfile(absfile, b'rb') as fp:
+                data = cast(bytes, fp.read())
             if not force and b'\0' in data:
                 self.error = 'binary file'
             else:
@@ -497,7 +497,7 @@ class FileData(_AbstractFileData):
                 lines += chunk.linecount
             self.diff = b''.join(values)
         else:
-            diffopts = patch.diffopts(repo.ui, {})
+            diffopts = patch.diffopts(repo.ui)
             diffopts.git = False
             newdate = dateutil.datestr(ctx.date())
             olddate = dateutil.datestr(ctx2.date())
@@ -551,7 +551,7 @@ class DirData(_AbstractFileData):
             m = ctx.match([b'path:%s' % self._wfile])
             self.diff = b''.join(ctx.diff(pctx, m))
         except (EnvironmentError, error.Abort) as e:
-            self.error = hglib.tounicode(str(e))
+            self.error = hglib.exception_str(e)
             return
 
         if not force:
@@ -577,7 +577,7 @@ class PatchFileData(_AbstractFileData):
             self.diff = ctx.thgmqpatchdata(wfile)
             flags = ctx.flags(wfile)
         except EnvironmentError as e:
-            self.error = hglib.tounicode(str(e))
+            self.error = hglib.exception_str(e)
             return
 
         if flags == b'x':
@@ -618,7 +618,7 @@ class PatchDirData(_AbstractFileData):
             self.diff = b''.join([ctx.thgmqpatchdata(f) for f in ctx.files()
                                   if f.startswith(self._wfile + b'/')])
         except EnvironmentError as e:
-            self.error = hglib.tounicode(str(e))
+            self.error = hglib.exception_str(e)
             return
 
         if not force:
@@ -817,7 +817,7 @@ class SubrepoData(_AbstractFileData):
                         return
                 except error.Abort as e:
                     self.error = (_('Error previewing subrepo: %s')
-                                  % hglib.tounicode(str(e))) + u'\n\n'
+                                  % hglib.exception_str(e)) + u'\n\n'
                     self.error += _('Subrepo may be damaged or '
                                     'inaccessible.')
                     return
@@ -882,7 +882,7 @@ class SubrepoData(_AbstractFileData):
                 self.flabel += lbl % hglib.tounicode(srepo.root)
         except (EnvironmentError, error.RepoError, error.Abort) as e:
             self.error = _('Error previewing subrepo: %s') % \
-                    hglib.tounicode(str(e))
+                    hglib.exception_str(e)
 
     def isDir(self) -> bool:
         return True
