@@ -14,7 +14,7 @@
 # this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-from __future__ import absolute_import
+
 
 from .qtcore import (
     QModelIndex,
@@ -38,6 +38,9 @@ if hglib.TYPE_CHECKING:
         List,
         Optional,
     )
+    from .qtcore import (
+        QAbstractItemModel,
+    )
     from .qtgui import (
         QWidget,
     )
@@ -69,7 +72,8 @@ class HgFileListView(QTreeView):
         return model
 
     def setModel(self, model):
-        # type: (manifestmodel.ManifestModel) -> None
+        # type: (QAbstractItemModel) -> None
+        assert isinstance(model, manifestmodel.ManifestModel)
         QTreeView.setModel(self, model)
         model.layoutChanged.connect(self._onLayoutChanged)
         model.revLoaded.connect(self._onRevLoaded)
