@@ -11,6 +11,10 @@ import difflib
 import os
 import re
 
+from typing import (
+    cast,
+)
+
 from . import qsci as Qsci
 from .qtcore import (
     QElapsedTimer,
@@ -33,6 +37,7 @@ from .qtgui import (
     QInputDialog,
     QKeySequence,
     QLabel,
+    QMouseEvent,
     QPalette,
     QShortcut,
     QStyle,
@@ -724,7 +729,7 @@ class _AbstractViewControl(QObject):
         return p
 
 
-_diffHeaderRegExp = re.compile("^@@ -[0-9]+,[0-9]+ \+[0-9]+,[0-9]+ @@")
+_diffHeaderRegExp = re.compile(r"^@@ -[0-9]+,[0-9]+ \+[0-9]+,[0-9]+ @@")
 
 class _DiffViewControl(_AbstractViewControl):
     """Display the unified diff in HgFileView"""
@@ -1002,7 +1007,7 @@ class _AnnotateViewControl(_AbstractViewControl):
         self._sci.markerDeleteAll()
         self._cmdsession.abort()
 
-    def eventFilter(self, watched, event):
+    def eventFilter(self, watched: QObject, event: QEvent) -> bool:
         # Python wrapper is deleted immediately before QEvent.Destroy
         try:
             sciviewport = self._sci.viewport()
@@ -1010,7 +1015,7 @@ class _AnnotateViewControl(_AbstractViewControl):
             sciviewport = None
         if watched is sciviewport:
             if event.type() == QEvent.Type.MouseMove:
-                line = self._sci.lineNearPoint(event.pos())
+                line = self._sci.lineNearPoint(cast(QMouseEvent, event).pos())
                 self._emitRevisionHintAtLine(line)
             return False
         return super(_AnnotateViewControl, self).eventFilter(watched, event)
