@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 from .qtcore import (
     QSettings,
@@ -225,7 +225,7 @@ class GraftDialog(QDialog):
             opts['continue'] = True
             args = []
         else:
-            args = [hglib.tounicode(str(s)) for s in self.sourcelist]
+            args = [str(s) for s in self.sourcelist]
         cmdline = hglib.buildcmdargs('graft', *args, **opts)
         sess = self._runCommand(cmdline)
         sess.commandFinished.connect(self._graftFinished)
@@ -314,7 +314,7 @@ class GraftDialog(QDialog):
         # type: (Text) -> None
         if cmd == 'resolve':
             dlg = resolve.ResolveDialog(self._repoagent, self)
-            dlg.exec_()
+            dlg.exec()
             self.checkResolve()
         else:
             self._wctxcleaner.runCleaner(cmd)
