@@ -18,7 +18,7 @@ of Graph instances that describe a revision set graph. These generators
 are used by repomodel.py which renders them on a widget.
 """
 
-from __future__ import absolute_import
+
 
 import collections
 import os
@@ -33,6 +33,9 @@ from mercurial import (
     pycompat,
     revset as revsetmod,
 )
+from mercurial.utils import (
+    urlutil,
+)
 
 from ..util import (
     obsoleteutil,
@@ -708,8 +711,22 @@ class ShallowFileDag(FileDag):
         path = self.path
 
         try:
-            # TODO: switch to one of the urlutil.get_*path() functions
-            dest = repo.ui.expandpath('default')
+            # ui.expandpath() was dropped in hg dcf983a5f906, and
+            # urlutil.get_unique_pull_path_obj() was added in hg f4626b74b941.
+            # Additionally, hg.peer() started taking a path object in hg
+            # aa36771ef505.  All of this landed in hg 6.4.
+
+            try:
+                # pytype: disable=module-attr
+                dest = urlutil.get_unique_pull_path_obj(
+                    b'getflogheads', repo.ui
+                )
+                # pytype: enable=module-attr
+            except AttributeError:
+                # pytype: disable=attribute-error
+                dest = repo.ui.expandpath(b'default')
+                # pytype: enable=attribute-error
+
             peer = hg.peer(repo, {}, dest)
         except error.RepoError:
             peer = None
@@ -718,7 +735,7 @@ class ShallowFileDag(FileDag):
         repoheads = set(repo.heads())
 
         # Get filelog heads from server and filter local heads with peer heads
-        if peer is not None and peer.capable('getflogheads'):
+        if peer is not None and peer.capable(b'getflogheads'):
             repoheads -= set(peer.heads())
             flogheads.update(set(peer.getflogheads(path)))
 
