@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import os
 import re
@@ -336,7 +336,7 @@ class SearchWidget(QWidget, qtlib.TaskWidget):
                 regexp = re.compile(pattern, icase and re.I or 0)
         except Exception as inst:
             msg = _('grep: invalid match pattern: %s\n') % \
-                    hglib.tounicode(str(inst))
+                    hglib.exception_str(inst)
             self.showMessage.emit(msg)
             return
 
@@ -366,7 +366,7 @@ class SearchWidget(QWidget, qtlib.TaskWidget):
             try:
                 ctx = hglib.revsymbol(self.repo, revstr or b'.')
             except error.RepoError as e:
-                msg = _('grep: %s\n') % hglib.tounicode(str(e))
+                msg = _('grep: %s\n') % hglib.exception_str(e)
                 self.showMessage.emit(msg)
                 return
             self.thread = CtxSearchThread(self.repo, regexp, ctx, inc, exc,
@@ -485,7 +485,7 @@ class HistorySearchThread(QThread):
             u = incrui(self.repo.ui)
             commands.grep(u, self.repo, self.pattern, **opts)
         except Exception as e:
-            self.showMessage.emit(str(e))
+            self.showMessage.emit(hglib.exception_str(e))
         except KeyboardInterrupt:
             self.showMessage.emit(_('Interrupted'))
         self.progress.emit(*cmdui.stopProgress(_('Searching')))
@@ -526,7 +526,7 @@ class CtxSearchThread(QThread):
             self.searchRepo(self.ctx, '', matchfn)
             self.completed = True
         except Exception as e:
-            self.showMessage.emit(hglib.tounicode(str(e)))
+            self.showMessage.emit(hglib.exception_str(e))
 
     def searchRepo(self, ctx, prefix, matchfn):
         topic = _('Searching')
@@ -644,7 +644,7 @@ class MatchTree(QTableView):
         if not self.selectionModel().selectedRows():
             return
         point = self.viewport().mapToGlobal(point)
-        self.contextmenu.exec_(point)
+        self.contextmenu.exec(point)
 
     def onSelectionChanged(self, selected, deselected):
         selrows = []
@@ -754,7 +754,7 @@ class MatchTree(QTableView):
                                                           files),
                                          {'change':crev})
                 if dlg:
-                    dlg.exec_()
+                    dlg.exec()
             rows = defer
 
 
