@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import os
 
@@ -303,11 +303,13 @@ class DetectRenameDialog(QDialog):
                       'destination file:\n%s. Aborting!') % udest)
                 return
             remdests[dest] = src
-        for dest, src in remdests.items():
-            if not os.path.exists(self.repo.wjoin(src)):
-                wctx.forget([src]) # !->R
-            wctx.copy(src, dest)
-            model.remove(dest)
+
+        with self.repo.wlock(), hglib.dirstate_changing_files(self.repo):
+            for dest, src in remdests.items():
+                if not os.path.exists(self.repo.wjoin(src)):
+                    wctx.forget([src]) # !->R
+                wctx.copy(src, dest)
+                model.remove(dest)
         self.matchAccepted.emit()
         self.refresh()
 
@@ -476,7 +478,7 @@ class RenameSearchThread(QThread):
         except KeyboardInterrupt:
             pass
         except Exception as e:
-            self.showMessage.emit(hglib.tounicode(str(e)))
+            self.showMessage.emit(hglib.exception_str(e))
         finally:
             self.threadid = None
 
