@@ -5,10 +5,9 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 from mercurial import (
-    encoding,
     pycompat,
     ui as uimod,
 )
@@ -54,58 +53,41 @@ class HgConfig(object):
 
     def configBool(self, section, name, default=UNSET_DEFAULT):
         # type: (Text, Text, bool) -> bool
-        data = self._ui.configbool(_tobytes(section), _tobytes(name),
+        data = self._ui.configbool(hglib.fromunicode(section), hglib.fromunicode(name),
                                    default=default)
         return bool(data)
 
     def configInt(self, section, name, default=UNSET_DEFAULT):
         # type: (Text, Text, int) -> int
-        data = self._ui.configint(_tobytes(section), _tobytes(name),
+        data = self._ui.configint(hglib.fromunicode(section), hglib.fromunicode(name),
                                   default=default)
         return int(data)
 
     def configString(self, section, name, default=UNSET_DEFAULT):
         # type: (Text, Text, Text) -> Text
         if default is not UNSET_DEFAULT:
-            default = _tobytes(default)
-        data = self._ui.config(_tobytes(section), _tobytes(name),
+            default = hglib.fromunicode(default)
+        data = self._ui.config(hglib.fromunicode(section), hglib.fromunicode(name),
                                default=default)
         if data is None:
             return ''
-        return _tostr(data)
+        return hglib.tounicode(data)
 
     def configStringList(self, section, name, default=UNSET_DEFAULT):
         # type: (Text, Text, List[Text]) -> List[Text]
         if default is not UNSET_DEFAULT:
-            default = pycompat.maplist(_tobytes, default)
-        data = self._ui.configlist(_tobytes(section), _tobytes(name),
+            default = pycompat.maplist(hglib.fromunicode, default)
+        data = self._ui.configlist(hglib.fromunicode(section), hglib.fromunicode(name),
                                    default=default)
-        return pycompat.maplist(_tostr, data)
+        return hglib.to_unicode_list(data)
 
     def configStringItems(self, section):
         # type: (Text) -> List[Tuple[Text, Text]]
         """Returns a list of string (key, value) pairs under the specified
         section"""
-        items = self._ui.configitems(_tobytes(section))
-        return [(_tostr(k), _tostr(v)) for k, v in items]
+        items = self._ui.configitems(hglib.fromunicode(section))
+        return [(hglib.tounicode(k), hglib.tounicode(v)) for k, v in items]
 
     def hasConfig(self, section, name):
         # type: (Text, Text) -> bool
-        return self._ui.hasconfig(_tobytes(section), _tobytes(name))
-
-
-if pycompat.ispy3:
-    _tostr = hglib.tounicode
-    _tobytes = hglib.fromunicode
-else:
-    def _tostr(s):
-        # keep ascii string as byte string on Python 2, which is supposedly
-        # faster and safer.
-        if encoding.isasciistr(s):
-            return s
-        return hglib.tounicode(s)
-
-    def _tobytes(s):
-        if not isinstance(s, pycompat.unicode):
-            return s
-        return hglib.fromunicode(s)
+        return self._ui.hasconfig(hglib.fromunicode(section), hglib.fromunicode(name))
