@@ -6,14 +6,10 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import os
 
-from mercurial import (
-    pycompat,
-)
-
 from .qtcore import (
     pyqtSignal,
     pyqtSlot,
@@ -116,7 +112,7 @@ class InitWidget(cmdui.AbstractCmdWidget):
 
     def destination(self):
         # type: () -> Text
-        return pycompat.unicode(self._dest_edit.text()).strip()
+        return self._dest_edit.text().strip()
 
     def _buildCommand(self):
         # type: () -> List[Text]
