@@ -8,7 +8,7 @@
 # Foundation; either version 2 of the License, or (at your option) any later
 # version.
 
-from __future__ import absolute_import
+
 
 import os
 import re
@@ -51,9 +51,9 @@ if hglib.TYPE_CHECKING:
     from typing import (
         Any,
         Dict,
+        Iterable,
         List,
         Optional,
-        Sequence,
         Text,
         Tuple,
         Union,
@@ -68,6 +68,7 @@ if hglib.TYPE_CHECKING:
         RepoAgent,
     )
     from ..util.typelib import (
+        Qt_ItemFlags,
         ThgContext,
     )
 
@@ -106,7 +107,7 @@ class ManifestModel(QAbstractItemModel):
         self._iconcache = {}  # (path, status, subkind): icon
         self._repoagent = repoagent
 
-        self._namefilter = pycompat.unicode(namefilter or '')
+        self._namefilter = namefilter if namefilter else ''
         assert all(c in 'MARSC' for c in statusfilter), repr(statusfilter)
         self._statusfilter = statusfilter
         self._changedfilesonly = False
@@ -117,7 +118,7 @@ class ManifestModel(QAbstractItemModel):
         self._rootpopulated = False
 
     def data(self, index, role=Qt.ItemDataRole.DisplayRole):
-        # type: (QModelIndex, Qt.ItemDataRole) -> Optional[Any]
+        # type: (QModelIndex, Qt.ItemDataRole) -> Any
         if not index.isValid():
             return
 
@@ -235,7 +236,7 @@ class ManifestModel(QAbstractItemModel):
         return e.isdir
 
     def mimeData(self, indexes):
-        # type: (Sequence[QModelIndex]) -> QMimeData
+        # type: (Iterable[QModelIndex]) -> QMimeData
         files = [self.filePath(i) for i in indexes if i.isValid()]
         ctx = self._rootentry.ctx
         if ctx.rev() is not None:
@@ -256,7 +257,7 @@ class ManifestModel(QAbstractItemModel):
         return ['text/uri-list']
 
     def flags(self, index):
-        # type: (QModelIndex) -> Qt.ItemFlags
+        # type: (QModelIndex) -> Qt_ItemFlags
         f = super(ManifestModel, self).flags(index)
         if not index.isValid():
             return f
@@ -281,7 +282,7 @@ class ManifestModel(QAbstractItemModel):
             return QModelIndex()
 
         try:
-            e = self._nodeop.findpath(self._rootentry, pycompat.unicode(path))
+            e = self._nodeop.findpath(self._rootentry, path)
         except KeyError:
             return QModelIndex()
 
@@ -372,7 +373,6 @@ class ManifestModel(QAbstractItemModel):
     def setNameFilter(self, pattern):
         # type: (Text) -> None
         """Filter file name by partial match of glob pattern"""
-        pattern = pycompat.unicode(pattern)
         if self._namefilter == pattern:
             return
         self._namefilter = pattern
@@ -388,7 +388,6 @@ class ManifestModel(QAbstractItemModel):
     def setStatusFilter(self, status):
         # type: (Text) -> None
         """Filter file tree by change status 'MARSC'"""
-        status = str(status)
         assert all(c in 'MARSC' for c in status), repr(status)
         if self._statusfilter == status:
             return  # for performance reason
@@ -799,7 +798,7 @@ class ManifestCompleter(QCompleter):
         >>> c.splitPath(u'foo/')
         [u'foo', u'']
         """
-        return pycompat.unicode(path).split('/')
+        return path.split('/')
 
     def pathFromIndex(self, index):
         # type: (QModelIndex) -> Text
