@@ -6,7 +6,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 from mercurial import (
     pycompat,
@@ -443,7 +443,7 @@ class MergePage(BasePage):
     def onLinkActivated(self, cmd):
         if cmd == 'resolve':
             dlg = resolve.ResolveDialog(self._repoagent, self)
-            dlg.exec_()
+            dlg.exec()
             if self.field('autoadvance'):
                 self.tryAutoAdvance(True)
             self.completeChanged.emit()
@@ -539,7 +539,10 @@ class CommitPage(BasePage):
             if self.isComplete():
                 self.wizard().next()
         actionEnter = QAction('alt-enter', self)
-        actionEnter.setShortcuts([Qt.Modifier.CTRL+Qt.Key.Key_Return, Qt.Modifier.CTRL+Qt.Key.Key_Enter])
+        actionEnter.setShortcuts([
+            qtlib.keyCombinationValue(Qt.Modifier.CTRL | Qt.Key.Key_Return),
+            qtlib.keyCombinationValue(Qt.Modifier.CTRL | Qt.Key.Key_Enter),
+        ])
         actionEnter.triggered.connect(tryperform)
         self.addAction(actionEnter)
 
@@ -588,7 +591,7 @@ class CommitPage(BasePage):
     def onLinkActivated(self, cmd):
         if cmd == 'view':
             dlg = status.StatusDialog(self._repoagent, [], {}, self)
-            dlg.exec_()
+            dlg.exec()
             self.refresh()
 
     def isComplete(self):
@@ -663,7 +666,7 @@ class CommitPage(BasePage):
         dlg.finished.connect(dlg.deleteLater)
         dlg.setWindowFlags(Qt.WindowType.Sheet)
         dlg.setWindowModality(Qt.WindowModality.WindowModal)
-        if dlg.exec_() == QDialog.DialogCode.Accepted:
+        if dlg.exec() == QDialog.DialogCode.Accepted:
             self.opts.update(dlg.outopts)
             self.refresh()
 
