@@ -66,7 +66,7 @@ class MessageEntry(qscilib.Scintilla):
         self.customContextMenuRequested.connect(self.menuRequested)
         self.applylexer()
 
-        self._re_boundary = re.compile('[0-9i#]+\.|\(?[0-9i#]+\)|\(@\)')
+        self._re_boundary = re.compile(r'[0-9i#]+\.|\(?[0-9i#]+\)|\(@\)')
 
     def setText(self, text):
         result = super(MessageEntry, self).setText(text)
