@@ -5,11 +5,15 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import os
 import re
 
+from typing import (
+    List,
+)
+
 from .qtcore import (
     QAbstractListModel,
     QByteArray,
@@ -80,7 +84,7 @@ def _checkForRejects(repo, rawoutput, parent=None):
                                   'file together with rejects?') % ufile,
                                 parent=parent):
             dlg = rejects.RejectsDialog(repo.ui, repo.wjoin(wfile), parent)
-            r = dlg.exec_()
+            r = dlg.exec()
             rejfiles[ufile] = (r == QDialog.DialogCode.Accepted)
 
     # empty rejfiles means we failed to parse output message
@@ -157,7 +161,7 @@ class QueueManagementActions(QObject):
         repoagent = self._repoagent.subRepoAgent(hglib.tounicode(repo.mq.path))
         dlg = commit.CommitDialog(repoagent, [], {}, self._parentWidget())
         dlg.finished.connect(dlg.deleteLater)
-        dlg.exec_()
+        dlg.exec()
 
     def switchQueue(self, name):
         return self._runQqueue(None, name)
@@ -209,7 +213,7 @@ class QueueManagementActions(QObject):
         dlg.setWindowTitle(title)
         dlg.setLabelText(labeltext)
         dlg.setOkButtonText(oktext)
-        if dlg.exec_():
+        if dlg.exec():
             return dlg.textValue()
 
     def _getExistingName(self, title, labeltext, oktext):
@@ -220,7 +224,7 @@ class QueueManagementActions(QObject):
         dlg.setComboBoxEditable(False)
         dlg.setComboBoxItems(self._existingNames())
         dlg.setTextValue(self._activeName())
-        if dlg.exec_():
+        if dlg.exec():
             return dlg.textValue()
 
     def abort(self):
@@ -332,7 +336,7 @@ class PatchQueueActions(QObject):
 
     def deletePatches(self, patches):
         dlg = qdelete.QDeleteDialog(patches, self._parentWidget())
-        if not dlg.exec_():
+        if not dlg.exec():
             return cmdcore.nullCmdSession()
         return self._runCommand('qdelete', patches, dlg.options())
 
@@ -340,7 +344,7 @@ class PatchQueueActions(QObject):
         lpatches = pycompat.maplist(hglib.fromunicode, patches)
         dlg = qfold.QFoldDialog(self._repoagent, lpatches, self._parentWidget())
         dlg.finished.connect(dlg.deleteLater)
-        if not dlg.exec_():
+        if not dlg.exec():
             return cmdcore.nullCmdSession()
         return self._runCommand('qfold', dlg.patches(), dlg.options())
 
@@ -368,8 +372,8 @@ class PatchQueueActions(QObject):
         dlg.setLabelText(labeltext)
         dlg.setTextValue(curvalue)
         dlg.setOkButtonText(oktext)
-        if dlg.exec_():
-            return pycompat.unicode(dlg.textValue())
+        if dlg.exec():
+            return dlg.textValue()
 
     def abort(self):
         self._cmdsession.abort()
@@ -404,7 +408,7 @@ class PatchQueueActions(QObject):
         dlg.finished.connect(dlg.deleteLater)
         dlg.setWindowFlags(Qt.WindowType.Sheet)
         dlg.setWindowModality(Qt.WindowModality.WindowModal)
-        if dlg.exec_() == QDialog.DialogCode.Accepted:
+        if dlg.exec() == QDialog.DialogCode.Accepted:
             self._opts.update(dlg.outopts)
 
 
@@ -416,7 +420,7 @@ class PatchQueueModel(QAbstractListModel):
         self._repoagent = repoagent
         self._repoagent.repositoryChanged.connect(self._updateCache)
         self._series = []
-        self._seriesguards = []
+        self._seriesguards: List[List[bytes]] = []
         self._statusmap = {}  # patch: applied/guarded/unguarded
         self._buildCache()
 
@@ -508,11 +512,10 @@ class PatchQueueModel(QAbstractListModel):
             return ''
         return hglib.tounicode(self._series[index.row()])
 
-    def patchGuards(self, index):
+    def patchGuards(self, index: QModelIndex) -> List[str]:
         if not index.isValid():
             return []
-        return pycompat.maplist(hglib.tounicode,
-                                self._seriesguards[index.row()])
+        return hglib.to_unicode_list(self._seriesguards[index.row()])
 
     def isApplied(self, index):
         if not index.isValid():
@@ -726,7 +729,7 @@ class MQPatchesWidget(QDockWidget):
         self._guardSelBtn.setMenu(menu)
         bbarhbox.addWidget(self._guardSelBtn)
 
-        self._qqueueComboWidget.activated[str].connect(self._onQQueueActivated)
+        self._qqueueComboWidget.activated[int].connect(self._onQQueueActivated)
 
         self._queueListWidget.activated.connect(self._onGotoPatch)
 
@@ -817,7 +820,7 @@ class MQPatchesWidget(QDockWidget):
                       text=uguards)
         if not ok or new == uguards:
             return
-        self._patchActions.guardPatch(patch, pycompat.unicode(new).split())
+        self._patchActions.guardPatch(patch, new.split())
 
     @pyqtSlot()
     def _onDelete(self):
@@ -878,8 +881,9 @@ class MQPatchesWidget(QDockWidget):
         self._setGuardsAct.setEnabled(len(indexes) == 1)
         self._qrenameAct.setEnabled(len(indexes) == 1)
 
-    @pyqtSlot(str)
-    def _onQQueueActivated(self, text):
+    @pyqtSlot(int)
+    def _onQQueueActivated(self, index):
+        text = self._qqueueComboWidget.itemText(index)
         if text == hglib.tounicode(self._repo.thgactivemqname):
             return
 
