@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 from .qtcore import (
     Qt,
@@ -45,8 +45,8 @@ class PerforcePending(QDialog):
         layout = QVBoxLayout()
         self.setLayout(layout)
 
-        clcombo = QComboBox()
-        layout.addWidget(clcombo)
+        self._clcombo = QComboBox()
+        layout.addWidget(self._clcombo)
 
         self.cslist = cslist.ChangesetList(repo)
         layout.addWidget(self.cslist)
@@ -64,19 +64,20 @@ class PerforcePending(QDialog):
         layout.addWidget(bb)
         self.bb = bb
 
-        clcombo.activated[str].connect(self.p4clActivated)
+        self._clcombo.activated[int].connect(self.p4clActivated)
         for changelist in self.pending:
-            clcombo.addItem(hglib.tounicode(changelist))
-        self.p4clActivated(clcombo.currentText())
+            self._clcombo.addItem(hglib.tounicode(changelist))
+        self.p4clActivated(self._clcombo.currentIndex())
 
         self.setWindowTitle(_('Pending Perforce Changelists - %s') %
                             repoagent.displayName())
         self.setWindowFlags(self.windowFlags() &
                             ~Qt.WindowType.WindowContextHelpButtonHint)
 
-    @pyqtSlot(str)
-    def p4clActivated(self, curcl):
+    @pyqtSlot(int)
+    def p4clActivated(self, curcl_idx):
         'User has selected a changelist, fill cslist'
+        curcl = self._clcombo.itemText(curcl_idx)
         repo = self._repoagent.rawRepo()
         curcl = hglib.fromunicode(curcl)
         try:
