@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 from mercurial import (
     pycompat,
@@ -232,7 +232,7 @@ class PhabReviewDialog(QDialog):
 
         history = {r.username: r for r in self._getreviewerhistory()}
         for reviewer in history.values():
-            item = QStandardItem(pycompat.unicode(reviewer))
+            item = QStandardItem(str(reviewer))
             item.setData(reviewer)
 
             # Must add to source model since setDynamicSortFilter() is True.
@@ -250,7 +250,7 @@ class PhabReviewDialog(QDialog):
                 username = qtlib.readString(s, "username")
                 reviewer = history.get(username)
                 if reviewer:
-                    witem = QListWidgetItem(pycompat.unicode(reviewer))
+                    witem = QListWidgetItem(str(reviewer))
                     witem.setData(Qt.ItemDataRole.UserRole + 1, reviewer)
                     reviewers.addItem(witem)
             s.endArray()
@@ -365,7 +365,7 @@ class PhabReviewDialog(QDialog):
         cmd.setWindowTitle(_('Posting Review'))
         cmd.setLogVisible(True)
         cmd.setSession(self._repoagent.runCommand(cmdline, self))
-        if cmd.exec_() == 0:
+        if cmd.exec() == 0:
             self._writereviewerhistory()
 
     def _initpreviewtab(self):
@@ -486,7 +486,7 @@ class PhabReviewDialog(QDialog):
 
             # https://github.com/google/pytype/issues/500
             u = user(username, realname, roles)  # pytype: disable=wrong-arg-count
-            item = QStandardItem(pycompat.unicode(u))
+            item = QStandardItem(str(u))
             item.setData(u)
 
             # Must add to source model since setDynamicSortFilter() is True.
