@@ -6,7 +6,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 from .qtcore import (
     QSettings,
@@ -179,7 +179,7 @@ class PickDialog(QDialog):
         if hglib.pick_in_progress(self.repo):
             opts['continue'] = True
         else:
-            opts['rev'] = hglib.tounicode(str(self.opts.get('rev')))
+            opts['rev'] = str(self.opts.get('rev'))
 
         cmdline = hglib.buildcmdargs('pick', **opts)
 
@@ -260,7 +260,7 @@ class PickDialog(QDialog):
         # type: (Text) -> None
         if cmd == 'resolve':
             dlg = resolve.ResolveDialog(self._repoagent, self)
-            dlg.exec_()
+            dlg.exec()
             self.checkResolve()
         else:
             self._wctxcleaner.runCleaner(cmd)
