@@ -17,7 +17,7 @@ https://foss.heptapod.net/mercurial/tortoisehg/thg-build-deps/mercurial-reviewbo
 More information can be found at http://www.mikeyd.com.au/tortoisehg-reviewboard
 """
 
-from __future__ import absolute_import
+
 
 from .qtcore import (
     QSettings,
@@ -288,12 +288,12 @@ class PostReviewDialog(QDialog):
     def getRepoId(self):
         # type: () -> Text
         comboText = self.qui.repo_id_combo.currentText().split(":")
-        return str(comboText[0])
+        return comboText[0]
 
     def getReviewId(self):
         # type: () -> Text
         comboText = self.qui.review_id_combo.currentText().split(":")
-        return str(comboText[0])
+        return comboText[0]
 
     def getSummary(self):
         # type: () -> Text
@@ -461,13 +461,13 @@ class PostReviewDialog(QDialog):
     def _captureOutput(self, msg, label):
         # type: (Text, Text) -> None
         if label != 'control':
-            self._cmdoutputs.append(pycompat.unicode(msg))
+            self._cmdoutputs.append(msg)
 
     @pyqtSlot()
     def onSettingsButtonClicked(self):
         # type: () -> None
         from tortoisehg.hgqt import settings
-        if settings.SettingsDialog(parent=self, focus='reviewboard.server').exec_():
+        if settings.SettingsDialog(parent=self, focus='reviewboard.server').exec():
             # not use repo.configChanged because it can clobber user input
             # accidentally.
             self.repo.invalidateui()  # force reloading config immediately
