@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import os
 import shutil
@@ -138,7 +138,7 @@ class PurgeDialog(QDialog):
                         trash = []
                     self.files = stat.unknown, stat.ignored, trash
                 except Exception as e:
-                    self.error = str(e)
+                    self.error = hglib.exception_str(e)
 
         self.th = CheckThread(self)
         self.th.finished.connect(self._checkCompleted)
@@ -151,7 +151,7 @@ class PurgeDialog(QDialog):
         self.bb.setEnabled(True)
         self.progress.emit(*cmdui.stopProgress(_('Checking')))
         if self.th.error:
-            self.showMessage.emit(hglib.tounicode(self.th.error))
+            self.showMessage.emit(self.th.error)
         else:
             self.showMessage.emit(_('Ready to purge.'))
             U, I, T = self.files
@@ -232,7 +232,7 @@ class PurgeThread(QThread):
             self.failures = self.purge(self.root, self.opts)
         except Exception as e:
             self.failures = None
-            self.showMessage.emit(hglib.tounicode(str(e)))
+            self.showMessage.emit(hglib.exception_str(e))
 
     def purge(self, root, opts):
         repo = hg.repository(hglib.loadui(), self.root)
