@@ -6,16 +6,12 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import os
 import re
 import weakref
 
-from mercurial import (
-    pycompat,
-)
-
 from .qsci import (
     QSCINTILLA_VERSION,
     QsciLexerProperties,
@@ -25,6 +21,7 @@ from .qtcore import (
     QObject,
     QEvent,
     QFile,
+    QFileDevice,
     QIODevice,
     QRect,
     QSettings,
@@ -306,7 +303,7 @@ class Scintilla(ScintillaCompat):
 
     def contextMenuEvent(self, event):
         menu = self.createEditorContextMenu()
-        menu.exec_(event.globalPos())
+        menu.exec(event.globalPos())
         menu.setParent(None)
 
     def createEditorContextMenu(self):
@@ -444,7 +441,7 @@ class Scintilla(ScintillaCompat):
             flags = 0
             if icase:
                 flags |= re.IGNORECASE
-            pat = re.compile(pycompat.unicode(match).encode('utf-8'), flags)
+            pat = re.compile(match.encode('utf-8'), flags)
         except re.error:
             return  # it could be partial pattern while user typing
 
@@ -465,7 +462,7 @@ class Scintilla(ScintillaCompat):
         #             p, len(m.group(0).encode('utf-8')))
         #
         # but it doesn't to avoid possible performance issue.
-        for m in pat.finditer(pycompat.unicode(self.text()).encode('utf-8')):
+        for m in pat.finditer(self.text().encode('utf-8')):
             self.SendScintilla(self.SCI_INDICATORFILLRANGE,
                                m.start(), m.end() - m.start())
             line = self.lineIndexFromPosition(m.start())[0]
@@ -490,7 +487,7 @@ class Scintilla(ScintillaCompat):
 
     def setDefaultEolMode(self):
         if self.lines():
-            mode = qsciEolModeFromLine(pycompat.unicode(self.text(0)))
+            mode = qsciEolModeFromLine(self.text(0))
         else:
             mode = qsciEolModeFromOs()
         self.setEolMode(mode)
@@ -715,7 +712,9 @@ class KeyPressInterceptor(QObject):
 def unbindConflictedKeys(sci):
     cmdset = sci.standardCommands()
     try:
-        cmd = cmdset.boundTo(Qt.Modifier.CTRL + Qt.Key.Key_L)
+        cmd = cmdset.boundTo(
+            qtlib.keyCombinationValue(Qt.Modifier.CTRL | Qt.Key.Key_L)
+        )
         if cmd:
             cmd.setKey(0)
     except AttributeError:  # old QScintilla does not have boundTo()
@@ -762,7 +761,7 @@ def readFile(editor, filename, encoding=None):
 
         f.seek(0)
         data = bytes(f.readAll())
-        if f.error():
+        if f.error() != QFileDevice.FileError.NoError:
             qtlib.WarningMsgBox(_('Unable to read file'),
                                 _('An error occurred while reading the file.'),
                                 f.errorString(), parent=editor)
@@ -778,7 +777,7 @@ def readFile(editor, filename, encoding=None):
                                 _('Could not translate the file content from '
                                   'native encoding.'),
                                 (_('Several characters would be lost.')
-                                 + '\n\n' + hglib.tounicode(str(inst))),
+                                 + '\n\n' + hglib.exception_str(inst)),
                                 parent=editor)
             text = data.decode(encoding, 'replace')
     else:
@@ -792,14 +791,14 @@ def writeFile(editor, filename, encoding=None):
     text = editor.text()
     try:
         if encoding:
-            data = pycompat.unicode(text).encode(encoding)
+            data = text.encode(encoding)
         else:
             data = hglib.fromunicode(text)
     except UnicodeEncodeError as inst:
         qtlib.WarningMsgBox(_('Unable to write file'),
                             _('Could not translate the file content to '
                               'native encoding.'),
-                            hglib.tounicode(str(inst)), parent=editor)
+                            hglib.exception_str(inst), parent=editor)
         return False
 
     f = QFile(filename)
@@ -868,7 +867,7 @@ def fileEditor(filename, **opts):
 
     if not readFile(editor, filename):
         return QDialog.DialogCode.Rejected
-    ret = dialog.exec_()
+    ret = dialog.exec()
     if ret != QDialog.DialogCode.Accepted:
         return ret
     if not writeFile(editor, filename):
