@@ -6,11 +6,10 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import gc
 import os
-import platform
 import signal
 import sys
 import traceback
@@ -27,12 +26,12 @@ from .qtcore import (
     QSocketNotifier,
     QT_API,
     QT_VERSION,
-    QT_VERSION_STR,
     QTimer,
     QTranslator,
     Qt,
     pyqtSignal,
     pyqtSlot,
+    qVersion,
 )
 from .qtgui import (
     QApplication,
@@ -46,7 +45,6 @@ from .qtnetwork import (
 from mercurial import (
     encoding,
     error,
-    pycompat,
 )
 from mercurial.utils import (
     procutil,
@@ -75,10 +73,12 @@ if os.name == 'nt' and getattr(sys, 'frozen', False):
     _mod = __import__(QT_API, globals(), locals(), ['QtSvg', 'QtXml'])
     _mod.QtSvg.__name__, _mod.QtXml.__name__  # no demandimport
 
-if PYQT_VERSION < 0x50000 or QT_VERSION < 0x50000:
-    sys.stderr.write('TortoiseHg requires at least Qt 5.0 and PyQt 5.0\n')
+# TODO: replace QT_VERSION, because it is the build time version, not
+#  necessarily the runtime version.
+if PYQT_VERSION < 0x50b00 or QT_VERSION < 0x50b00:
+    sys.stderr.write('TortoiseHg requires at least Qt 5.11 and PyQt 5.11\n')
     sys.stderr.write('You have Qt %s and PyQt %s\n' %
-                     (QT_VERSION_STR, PYQT_VERSION_STR))
+                     (qVersion(), PYQT_VERSION_STR))
     sys.exit(-1)
 
 if getattr(sys, 'frozen', False) and os.name == 'nt':
@@ -109,7 +109,7 @@ _recoverableexc = {
 def earlyExceptionMsgBox(e):
     """Show message for recoverable error before the QApplication is started"""
     opts = {'cmd': ' '.join(sys.argv[1:]),
-            'values': [hglib.tounicode(str(e))],
+            'values': [hglib.exception_str(e)],
             'error': traceback.format_exc(),
             'nofork': True}
     errstring = _recoverableexc[e.__class__]
@@ -122,8 +122,8 @@ def earlyExceptionMsgBox(e):
         opts['values'] += [hglib.tounicode(e.location)]
     if not QApplication.instance():
         main = QApplication(sys.argv)
-    dlg = bugreport.ExceptionMsgBox(hglib.tounicode(str(e)), errstring, opts)
-    dlg.exec_()
+    dlg = bugreport.ExceptionMsgBox(hglib.exception_str(e), errstring, opts)
+    dlg.exec()
 
 def earlyBugReport(e):
     """Show generic errors before the QApplication is started"""
@@ -132,7 +132,7 @@ def earlyBugReport(e):
     if not QApplication.instance():
         main = QApplication(sys.argv)
     dlg = bugreport.BugReport(opts)
-    dlg.exec_()
+    dlg.exec()
 
 class ExceptionCatcher(QObject):
     """Catch unhandled exception raised inside Qt event loop"""
@@ -205,18 +205,29 @@ class ExceptionCatcher(QObject):
         parent = self._mainapp.activeWindow()
         if (len(set(e[0] for e in self.errors)) == 1
             and etype in _recoverableexc):
-            opts['values'] = evalue
+            opts['values'] = [hglib.exception_str(evalue)]
             errstr = _recoverableexc[etype]
             if etype is error.Abort and evalue.hint:
                 errstr = u''.join([errstr, u'<br><b>', _('hint:'),
                                    u'</b> %(arg1)s'])
-                opts['values'] = [str(evalue), evalue.hint]
-            dlg = bugreport.ExceptionMsgBox(hglib.tounicode(str(evalue)),
+                opts['values'] = [
+                    hglib.exception_str(evalue), hglib.tounicode(evalue.hint)
+                ]
+            elif etype is error.ConfigError and evalue.location:
+                # If ConfigError contained a location, the config file couldn't
+                # be parsed at all. So '#edit:<location>' is the only way to
+                # fix.
+                errstr = _recoverableexc[error.ParseError]
+                opts['values'] += [hglib.tounicode(evalue.location)]
+            elif etype is error.ParseError and evalue.location:
+                opts['values'] += [hglib.tounicode(evalue.location)]
+
+            dlg = bugreport.ExceptionMsgBox(hglib.exception_str(evalue),
                                             errstr, opts, parent=parent)
-            dlg.exec_()
+            dlg.exec()
         else:
             dlg = bugreport.BugReport(opts, parent=parent)
-            dlg.exec_()
+            dlg.exec()
 
     def _printexception(self):
         for args in self.errors:
@@ -322,7 +333,9 @@ class GarbageCollector(QObject):
     def debug_cycles(self):
         gc.collect()
         for obj in gc.garbage:
-            self._ui.debug(b'%s, %r, %s\n' % (obj, obj, type(obj)))
+            self._ui.debug(
+                hglib.fromunicode('%s, %r, %s\n' % (obj, obj, type(obj)))
+            )
 
 
 def allowSetForegroundWindow(processid=-1):
@@ -372,17 +385,67 @@ def connectToExistingWorkbench(root, revset=None):
     return False
 
 
-def _fixapplicationfont():
-    if os.name != 'nt':
+def _fixapplicationfont(ui):
+    if (os.name != 'nt'
+        or QT_VERSION >= 0x060000
+        or not ui.configbool(b'experimental', b'thg.fix-app-font')):
         return
     try:
-        import win32gui, win32con  # pytype: disable=import-error
+        import ctypes, win32con  # pytype: disable=import-error
     except ImportError:
         return
 
+    class LOGFONTW(ctypes.Structure):
+        _fields_ = [
+            ('lfHeight', ctypes.wintypes.LONG),
+            ('lfWidth', ctypes.wintypes.LONG),
+            ('lfEscapement', ctypes.wintypes.LONG),
+            ('lfOrientation', ctypes.wintypes.LONG),
+            ('lfWeight', ctypes.wintypes.LONG),
+            ('lfItalic', ctypes.wintypes.BYTE),
+            ('lfUnderline', ctypes.wintypes.BYTE),
+            ('lfStrikeOut', ctypes.wintypes.BYTE),
+            ('lfCharSet', ctypes.wintypes.BYTE),
+            ('lfOutPrecision', ctypes.wintypes.BYTE),
+            ('lfClipPrecision', ctypes.wintypes.BYTE),
+            ('lfQuality', ctypes.wintypes.BYTE),
+            ('lfPitchAndFamily', ctypes.wintypes.BYTE),
+            ('lfFaceName', ctypes.wintypes.WCHAR * 32),
+        ]
+
+    class NONCLIENTMETRICSW(ctypes.Structure):
+        _fields_ = [
+            ('cbSize', ctypes.wintypes.UINT),
+            ('iBorderWidth', ctypes.c_int),
+            ('iScrollWidth', ctypes.c_int),
+            ('iScrollHeight', ctypes.c_int),
+            ('iCaptionWidth', ctypes.c_int),
+            ('iCaptionHeight', ctypes.c_int),
+            ('lfCaptionFont', LOGFONTW),
+            ('iSmCaptionWidth', ctypes.c_int),
+            ('iSmCaptionHeight', ctypes.c_int),
+            ('lfSmCaptionFont', LOGFONTW),
+            ('iMenuWidth', ctypes.c_int),
+            ('iMenuHeight', ctypes.c_int),
+            ('lfMenuFont', LOGFONTW),
+            ('lfStatusFont', LOGFONTW),
+            ('lfMessageFont', LOGFONTW),
+            ('iPaddedBorderWidth', ctypes.c_int),
+        ]
+
+    ncm = NONCLIENTMETRICSW()
+    size = ctypes.sizeof(ncm)
+    ncm.cbSize = size
+
+    user32 = ctypes.windll.user32  # pytype: disable=module-attr
+
     # use configurable font like GTK, Mozilla XUL or Eclipse SWT
-    ncm = win32gui.SystemParametersInfo(win32con.SPI_GETNONCLIENTMETRICS)
-    lf = ncm['lfMessageFont']
+    if not user32.SystemParametersInfoForDpi(
+        win32con.SPI_GETNONCLIENTMETRICS, size, ctypes.byref(ncm), 0, 96
+    ):
+        return
+
+    lf = ncm.lfMessageFont
     f = QFont(hglib.tounicode(lf.lfFaceName))
     f.setItalic(lf.lfItalic)
     if lf.lfWeight != win32con.FW_DONTCARE:
@@ -390,7 +453,7 @@ def _fixapplicationfont():
                    (700, QFont.Weight.Bold), (800, QFont.Weight.Black)]
         n, w = [e for e in weights if e[0] <= lf.lfWeight][-1]
         f.setWeight(w)
-    f.setPixelSize(abs(lf.lfHeight))
+    f.setPointSizeF((abs(lf.lfHeight) * 72.0) / 96.0)
     QApplication.setFont(f, 'QWidget')
 
 def _gettranslationpath():
@@ -403,7 +466,7 @@ def _gettranslationpath():
         # PyQt 5.13.2/Qt 5.9.9
         return QLibraryInfo.location(QLibraryInfo.TranslationsPath)
     else:
-        return QLibraryInfo.location(QLibraryInfo.LibraryPath.TranslationsPath)
+        return QLibraryInfo.path(QLibraryInfo.LibraryPath.TranslationsPath)
     # pytype: enable=attribute-error
 
 class QtRunner(QObject):
@@ -436,14 +499,17 @@ class QtRunner(QObject):
 
         self._ui = ui
         self._config = hgconfig.HgConfig(ui)
-        self._mainapp = QApplication(sys.argv)
 
         if QT_API == "PyQt5":
             # pytype: disable=attribute-error
-            self._mainapp.setAttribute(Qt.AA_UseHighDpiPixmaps, True)
+            QApplication.setAttribute(Qt.AA_UseHighDpiPixmaps, True)
+            QApplication.setAttribute(Qt.AA_EnableHighDpiScaling, True)
             # pytype: enable=attribute-error
+
         if sys.platform == 'darwin':
-            self._mainapp.setAttribute(Qt.ApplicationAttribute.AA_DontShowIconsInMenus, True)
+            QApplication.setAttribute(Qt.ApplicationAttribute.AA_DontShowIconsInMenus, True)
+
+        self._mainapp = QApplication(sys.argv)
 
         self._exccatcher = ExceptionCatcher(ui, self._mainapp, self)
         self._gc = GarbageCollector(ui, self)
@@ -458,7 +524,7 @@ class QtRunner(QObject):
         self._fixlibrarypaths()
         self._installtranslator()
         QFont.insertSubstitutions('monospace', ['monaco', 'courier new'])
-        _fixapplicationfont()
+        _fixapplicationfont(ui)
         qtlib.configstyles(ui)
         qtlib.initfontcache(ui)
         self._mainapp.setWindowIcon(qtlib.geticon('thg'))
@@ -468,7 +534,10 @@ class QtRunner(QObject):
 
         self._repomanager = thgrepo.RepoManager(ui, self)
         self._reporeleaser = releaser = QSignalMapper(self)
-        releaser.mapped[pycompat.unicode].connect(self._repomanager.releaseRepoAgent)
+
+        qtlib.getMappedStringSignal(releaser).connect(
+            self._repomanager.releaseRepoAgent
+        )
 
         # stop services after control returns to the main event loop
         self._mainapp.setQuitOnLastWindowClosed(False)
@@ -490,7 +559,7 @@ class QtRunner(QObject):
             if thginithook is not None:
                 thginithook()
 
-            return self._mainapp.exec_()
+            return self._mainapp.exec()
         finally:
             self._exccatcher.release()
             self._mainapp = self._ui = self._config = None
