@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import os
 import sys
@@ -233,7 +233,7 @@ class QuickOpDialog(QDialog):
                     repostate = self.repo.status()
                 except (EnvironmentError, error.Abort) as e:
                     qtlib.WarningMsgBox(_('Unable to read repository status'),
-                                        hglib.tounicode(str(e)), parent=self)
+                                        hglib.exception_str(e), parent=self)
                     return
 
             if not self.chk.isChecked():
