@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 from .qtcore import (
     QSettings,
@@ -243,8 +243,8 @@ class RebaseDialog(QDialog):
                 opts['svn'] = True
             else:
                 sourcearg = _SOURCE_SPECS[self._sourcegroup.checkedId()][0]
-                opts[sourcearg] = hglib.tounicode(str(self.opts.get('source')))
-                opts['dest'] = hglib.tounicode(str(self.opts.get('dest')))
+                opts[sourcearg] = str(self.opts.get('source'))
+                opts['dest'] = str(self.opts.get('dest'))
         cmdline = hglib.buildcmdargs('rebase', **opts)
         sess = self._runCommand(cmdline)
         sess.commandFinished.connect(self._rebaseFinished)
@@ -329,7 +329,7 @@ class RebaseDialog(QDialog):
         # type: (Text) -> None
         if cmd == 'resolve':
             dlg = resolve.ResolveDialog(self._repoagent, self)
-            dlg.exec_()
+            dlg.exec()
             self.checkResolve()
         else:
             self._wctxcleaner.runCleaner(cmd)
