@@ -6,7 +6,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import os
 import sys
@@ -27,7 +27,6 @@ from .qtgui import (
 )
 
 from mercurial import (
-    pycompat,
     util,
 )
 
@@ -119,11 +118,11 @@ class RenameWidget(cmdui.AbstractCmdWidget):
 
     def source(self):
         # type: () -> Text
-        return pycompat.unicode(self.src_txt.text())
+        return self.src_txt.text()
 
     def destination(self):
         # type: () -> Text
-        return pycompat.unicode(self.dest_txt.text())
+        return self.dest_txt.text()
 
     def _sourceFile(self):
         # type: () -> Text
