@@ -14,7 +14,7 @@
 # this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-from __future__ import absolute_import
+
 
 import binascii
 import os
@@ -69,6 +69,9 @@ if hglib.TYPE_CHECKING:
         thgrepo,
         filedialogs,
     )
+    from ..util.typelib import (
+        Qt_ItemFlags,
+    )
 
     # _UnfilteredRepoAgentProxy is a short term hack, so don't use this type
     # for RepoAgent everywhere.
@@ -354,7 +357,6 @@ class HgRepoListModel(QAbstractTableModel):
 
     def setRevset(self, revspec):
         # type: (Text) -> None
-        revspec = pycompat.unicode(revspec)
         if revspec == self._revspec:
             return
         self._revspec = revspec
@@ -589,7 +591,7 @@ class HgRepoListModel(QAbstractTableModel):
             if 'THGDEBUG' in os.environ:
                 raise
             if role == Qt.ItemDataRole.DisplayRole:
-                return hglib.tounicode(str(e))
+                return hglib.exception_str(e)
             else:
                 return None
 
@@ -655,7 +657,7 @@ class HgRepoListModel(QAbstractTableModel):
         return None
 
     def flags(self, index):
-        # type: (QModelIndex) -> int
+        # type: (QModelIndex) -> Qt_ItemFlags
         flags = super(HgRepoListModel, self).flags(index)
         if not index.isValid():
             return flags
@@ -933,7 +935,7 @@ class HgRepoListModel(QAbstractTableModel):
             cvt = extra.get(b'convert_revision', b'')
             if cvt:
                 if cvt.startswith(b'svn:'):
-                    return pycompat.unicode(cvt.split(b'@')[-1], 'utf-8', 'replace')
+                    return str(cvt.split(b'@')[-1], 'utf-8', 'replace')
                 if len(cvt) == 40:
                     try:
                         binascii.unhexlify(cvt)
