@@ -30,11 +30,13 @@ from .qtgui import (
     QAction,
     QApplication,
     QDockWidget,
+    QDropEvent,
     QFileDialog,
     QFontMetrics,
     QFrame,
     QMenu,
     QMessageBox,
+    QMouseEvent,
     QTreeView,
     QVBoxLayout,
 )
@@ -108,8 +110,8 @@ class RepoTreeView(QTreeView):
                 self.setState(QAbstractItemView.State.DraggingState)
                 break
 
-    def dropLocation(self, event):
-        index = self.indexAt(event.pos())
+    def dropLocation(self, event: QDropEvent):
+        index = self.indexAt(qtlib.qDropEventPosition(event))
 
         # Determine where the item was dropped.
         target = index.internalPointer()
@@ -146,7 +148,7 @@ class RepoTreeView(QTreeView):
 
         super(RepoTreeView, self).startDrag(supportedActions)
 
-    def dropEvent(self, event):
+    def dropEvent(self, event: QDropEvent):
         data = event.mimeData()
         index, group, row = self.dropLocation(event)
 
@@ -191,7 +193,7 @@ class RepoTreeView(QTreeView):
                 return
         super(RepoTreeView, self).keyPressEvent(event)
 
-    def mouseMoveEvent(self, event):
+    def mouseMoveEvent(self, event: QMouseEvent) -> None:
         self.msg  = ''
         pos = event.pos()
         idx = self.indexAt(pos)
@@ -210,7 +212,7 @@ class RepoTreeView(QTreeView):
         if self.msg != '':
             self.showMessage.emit('')
 
-    def mouseDoubleClickEvent(self, event):
+    def mouseDoubleClickEvent(self, event: QMouseEvent) -> None:
         index = self.indexAt(event.pos())
         if index.isValid() and index.internalPointer().isRepo():
             self.openRequested.emit(index)
@@ -584,13 +586,29 @@ class RepoRegistryView(QDockWidget):
         FD = QFileDialog
         path = FD.getExistingDirectory(caption=caption,
                                        options=QFileDialog.Option.ShowDirsOnly | QFileDialog.Option.ReadOnly)
-        if path:
-            m = self.tview.model()
-            assert m is not None
-            uroot = paths.find_root(path)
-            if uroot and not m.isKnownRepoRoot(uroot, standalone=True):
-                index = m.addRepo(uroot, parent=self.tview.currentIndex())
-                self._scanAddedRepo(index)
+        if not path:
+            # the used pressed "cancel"
+            return
+        m = self.tview.model()
+        assert m is not None
+        uroot = paths.find_root(path)
+        if not uroot:
+            qtlib.WarningMsgBox(
+                _('Repository not found'),
+                _('The selected directory (%s) does not appear to be '
+                  'a mercurial repository') % path,
+                parent=self)
+            return
+        if m.isKnownRepoRoot(uroot, standalone=True):
+            qtlib.InfoMsgBox(
+                _('Repository already in registry'),
+                _('The selected repository (%s) is already present in '
+                  'the registry. Not adding it again.') % uroot,
+                parent=self)
+            return
+        # this is a new mercurial repo, let's add it to the registry
+        index = m.addRepo(uroot, parent=self.tview.currentIndex())
+        self._scanAddedRepo(index)
 
     def addSubrepo(self):
         'menu action handler for adding a new subrepository'
@@ -601,123 +619,122 @@ class RepoRegistryView(QDockWidget):
         FD = QFileDialog
         path = FD.getExistingDirectory(caption=caption,
             directory=root, options=QFileDialog.Option.ShowDirsOnly | QFileDialog.Option.ReadOnly)
-        if path:
-            path = os.path.normpath(path)
-            sroot = paths.find_root(path)
+        if not path:
+            # the used pressed "cancel"
+            return
+        path = os.path.normpath(path)
+        sroot = paths.find_root(path)
 
-            root = os.path.normcase(os.path.normpath(root))
+        root = os.path.normcase(os.path.normpath(root))
 
-            if not sroot:
-                qtlib.WarningMsgBox(_('Cannot add subrepository'),
-                    _('%s is not a valid repository') % path,
-                    parent=self)
+        if not sroot:
+            qtlib.WarningMsgBox(_('Cannot add subrepository'),
+                _('%s is not a valid repository') % path,
+                parent=self)
+            return
+        if not os.path.isdir(sroot):
+            qtlib.WarningMsgBox(_('Cannot add subrepository'),
+                _('"%s" is not a folder') % sroot,
+                parent=self)
+            return
+        if os.path.normcase(sroot) == root:
+            qtlib.WarningMsgBox(_('Cannot add subrepository'),
+                _('A repository cannot be added as a subrepo of itself'),
+                parent=self)
+            return
+        if root != paths.find_root(os.path.dirname(os.path.normcase(path))):
+            qtlib.WarningMsgBox(_('Cannot add subrepository'),
+                _('The selected folder:<br><br>%s<br><br>'
+                'is not inside the target repository.<br><br>'
+                'This may be allowed but is greatly discouraged.<br>'
+                'If you want to add a non trivial subrepository mapping '
+                'you must manually edit the <i>.hgsub</i> file') % root, parent=self)
+            return
+        # The selected path is the root of a repository that is inside
+        # the selected repository
+
+        # Use forward slashes for relative subrepo root paths
+        srelroot = util.pconvert(hglib.fromunicode(sroot[len(root)+1:]))
+
+        # Is is already on the selected repository substate list?
+        try:
+            repo = hg.repository(hglib.loadui(),
+                                 hglib.fromunicode(root))
+        except:
+            qtlib.WarningMsgBox(_('Cannot open repository'),
+                _('The selected repository:<br><br>%s<br><br>'
+                'cannot be open!') % root, parent=self)
+            return
+
+        if srelroot in repo[b'.'].substate:
+            qtlib.WarningMsgBox(_('Subrepository already exists'),
+                _('The selected repository:<br><br>%s<br><br>'
+                'is already a subrepository of:<br><br>%s<br><br>'
+                'as: "%s"') % (sroot, root, hglib.tounicode(srelroot)),
+                                parent=self)
+            return
+        # Read the current .hgsub file contents
+        lines = []
+        hasHgsub = os.path.exists(repo.wjoin(b'.hgsub'))
+        if hasHgsub:
+            try:
+                with repo.wvfs(b'.hgsub', b'r') as fsub:
+                    lines = fsub.readlines()
+            except:
+                qtlib.WarningMsgBox(
+                    _('Failed to add subrepository'),
+                    _('Cannot open the .hgsub file in:<br><br>%s') \
+                    % root, parent=self)
                 return
-            elif not os.path.isdir(sroot):
-                qtlib.WarningMsgBox(_('Cannot add subrepository'),
-                    _('"%s" is not a folder') % sroot,
-                    parent=self)
+
+        # Make sure that the selected subrepo (or one of its
+        # subrepos!) is not already on the .hgsub file
+        linesep = b''
+        # On Windows case is unimportant, while on posix it is
+        srelrootnormcase = os.path.normcase(srelroot)
+        for line in lines:
+            spath = line.split(b"=")[0].strip()
+            if not spath:
+                continue
+            uline = hglib.tounicode(line)
+            if not linesep:
+                linesep = hglib.fromunicode(hglib.getLineSeparator(uline))
+            spath = util.pconvert(spath)
+            if os.path.normcase(spath) == srelrootnormcase:
+                qtlib.WarningMsgBox(
+                    _('Failed to add repository'),
+                    _('The .hgsub file already contains the '
+                    'line:<br><br>%s') % uline, parent=self)
                 return
-            elif os.path.normcase(sroot) == root:
-                qtlib.WarningMsgBox(_('Cannot add subrepository'),
-                    _('A repository cannot be added as a subrepo of itself'),
-                    parent=self)
-                return
-            elif root != paths.find_root(os.path.dirname(os.path.normcase(path))):
-                qtlib.WarningMsgBox(_('Cannot add subrepository'),
-                    _('The selected folder:<br><br>%s<br><br>'
-                    'is not inside the target repository.<br><br>'
-                    'This may be allowed but is greatly discouraged.<br>'
-                    'If you want to add a non trivial subrepository mapping '
-                    'you must manually edit the <i>.hgsub</i> file') % root, parent=self)
-                return
-            else:
-                # The selected path is the root of a repository that is inside
-                # the selected repository
+        if not linesep:
+            linesep = pycompat.oslinesep
 
-                # Use forward slashes for relative subrepo root paths
-                srelroot = util.pconvert(hglib.fromunicode(sroot[len(root)+1:]))
+        # Append the new subrepo to the end of the .hgsub file
+        lines.append(b'%s = %s' % (srelroot, srelroot))
+        lines = [line.strip(linesep) for line in lines]
 
-                # Is is already on the selected repository substate list?
-                try:
-                    repo = hg.repository(hglib.loadui(),
-                                         hglib.fromunicode(root))
-                except:
-                    qtlib.WarningMsgBox(_('Cannot open repository'),
-                        _('The selected repository:<br><br>%s<br><br>'
-                        'cannot be open!') % root, parent=self)
-                    return
+        # and update the .hgsub file
+        try:
+            with repo.wvfs(b'.hgsub', b'w') as fsub:
+                fsub.write(linesep.join(lines) + linesep)
 
-                if srelroot in repo[b'.'].substate:
-                    qtlib.WarningMsgBox(_('Subrepository already exists'),
-                        _('The selected repository:<br><br>%s<br><br>'
-                        'is already a subrepository of:<br><br>%s<br><br>'
-                        'as: "%s"') % (sroot, root, hglib.tounicode(srelroot)),
-                                        parent=self)
-                    return
-                else:
-                    # Read the current .hgsub file contents
-                    lines = []
-                    hasHgsub = os.path.exists(repo.wjoin(b'.hgsub'))
-                    if hasHgsub:
-                        try:
-                            with repo.wvfs(b'.hgsub', b'r') as fsub:
-                                lines = fsub.readlines()
-                        except:
-                            qtlib.WarningMsgBox(
-                                _('Failed to add subrepository'),
-                                _('Cannot open the .hgsub file in:<br><br>%s') \
-                                % root, parent=self)
-                            return
-
-                    # Make sure that the selected subrepo (or one of its
-                    # subrepos!) is not already on the .hgsub file
-                    linesep = b''
-                    # On Windows case is unimportant, while on posix it is
-                    srelrootnormcase = os.path.normcase(srelroot)
-                    for line in lines:
-                        spath = line.split(b"=")[0].strip()
-                        if not spath:
-                            continue
-                        uline = hglib.tounicode(line)
-                        if not linesep:
-                            linesep = hglib.fromunicode(hglib.getLineSeparator(uline))
-                        spath = util.pconvert(spath)
-                        if os.path.normcase(spath) == srelrootnormcase:
-                            qtlib.WarningMsgBox(
-                                _('Failed to add repository'),
-                                _('The .hgsub file already contains the '
-                                'line:<br><br>%s') % uline, parent=self)
-                            return
-                    if not linesep:
-                        linesep = pycompat.oslinesep
-
-                    # Append the new subrepo to the end of the .hgsub file
-                    lines.append(b'%s = %s' % (srelroot, srelroot))
-                    lines = [line.strip(linesep) for line in lines]
-
-                    # and update the .hgsub file
-                    try:
-                        with repo.wvfs(b'.hgsub', b'w') as fsub:
-                            fsub.write(linesep.join(lines) + linesep)
-
-                        if not hasHgsub:
-                            commands.add(hglib.loadui(),
-                                         repo, repo.wjoin(b'.hgsub'))
-                        qtlib.InfoMsgBox(
-                            _('Subrepo added to .hgsub file'),
-                            _('The selected subrepo:<br><br><i>%s</i><br><br>'
-                            'has been added to the .hgsub file of the repository:<br><br><i>%s</i><br><br>'
-                            'Remember that in order to finish adding the '
-                            'subrepo <i>you must still <u>commit</u></i> the '
-                            'changes to the .hgsub file in order to confirm '
-                            'the addition of the subrepo.') \
-                            % (hglib.tounicode(srelroot), root), parent=self)
-                    except:
-                        qtlib.WarningMsgBox(
-                            _('Failed to add repository'),
-                            _('Cannot update the .hgsub file in:<br><br>%s') \
-                            % root, parent=self)
-                return
+            if not hasHgsub:
+                commands.add(hglib.loadui(),
+                             repo, repo.wjoin(b'.hgsub'))
+            qtlib.InfoMsgBox(
+                _('Subrepo added to .hgsub file'),
+                _('The selected subrepo:<br><br><i>%s</i><br><br>'
+                'has been added to the .hgsub file of the repository:<br><br><i>%s</i><br><br>'
+                'Remember that in order to finish adding the '
+                'subrepo <i>you must still <u>commit</u></i> the '
+                'changes to the .hgsub file in order to confirm '
+                'the addition of the subrepo.') \
+                % (hglib.tounicode(srelroot), root), parent=self)
+        except:
+            qtlib.WarningMsgBox(
+                _('Failed to add repository'),
+                _('Cannot update the .hgsub file in:<br><br>%s') \
+                % root, parent=self)
 
     def removeSubrepo(self):
         'menu action handler for removing an existing subrepository'
