@@ -24,6 +24,7 @@ from .qtgui import (
     QActionGroup,
     QKeySequence,
     QMenu,
+    QMouseEvent,
     QShortcut,
     QStackedLayout,
     QTabBar,
@@ -46,7 +47,7 @@ from . import (
 
 class _TabBar(QTabBar):
 
-    def mouseReleaseEvent(self, event):
+    def mouseReleaseEvent(self, event: QMouseEvent) -> None:
         if event.button() == Qt.MouseButton.MiddleButton:
             self.tabCloseRequested.emit(self.tabAt(event.pos()))
         super(_TabBar, self).mouseReleaseEvent(event)
