@@ -5,16 +5,27 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import os
 import re
 
+from typing import (
+    Dict,
+    Iterable,
+    List,
+    Optional,
+    Type,
+    TypeVar,
+    Union,
+)
+
 from .qtcore import (
     Qt,
 )
 from .qtgui import (
     QApplication,
+    QIcon,
     QMessageBox,
     QStyle,
 )
@@ -22,6 +33,7 @@ from .qtgui import (
 from mercurial import (
     error,
     hg,
+    localrepo,
     node,
     pycompat,
     util,
@@ -37,17 +49,24 @@ from . import (
     qtlib,
 )
 
-def _dumpChild(xw, parent):
+
+_TAlienSubrepoItem = TypeVar('_TAlienSubrepoItem', bound='AlienSubrepoItem')
+_TRepoGroupItem = TypeVar('_TRepoGroupItem', bound='RepoGroupItem')
+_TRepoItem = TypeVar('_TRepoItem', bound='RepoItem')
+_TRepoTreeItem = TypeVar('_TRepoTreeItem', bound='RepoTreeItem')
+
+
+def _dumpChild(xw, parent: "RepoTreeItem") -> None:
     for c in parent.childs:
         c.dumpObject(xw)
 
-def undumpObject(xr):
+def undumpObject(xr) -> "RepoTreeItem":
     xmltagname = str(xr.name())
     obj = _xmlUndumpMap[xmltagname](xr)
     assert obj.xmltagname == xmltagname, (obj.xmltagname, xmltagname)
     return obj
 
-def _undumpChild(xr, parent, undump=undumpObject):
+def _undumpChild(xr, parent: "RepoTreeItem", undump=undumpObject) -> None:
     while not xr.atEnd():
         xr.readNext()
         if xr.isStartElement():
@@ -59,7 +78,7 @@ def _undumpChild(xr, parent, undump=undumpObject):
         elif xr.isEndElement():
             break
 
-def flatten(root, stopfunc=None):
+def flatten(root: "RepoTreeItem", stopfunc=None) -> Iterable["RepoTreeItem"]:
     """Iterate root and its child items recursively until stop condition"""
     yield root
     if stopfunc and stopfunc(root):
@@ -68,7 +87,7 @@ def flatten(root, stopfunc=None):
         for e in flatten(c, stopfunc):
             yield e
 
-def find(root, targetfunc, stopfunc=None):
+def find(root: "RepoTreeItem", targetfunc, stopfunc=None) -> "RepoTreeItem":
     """Search recursively for item of which targetfunc evaluates to True"""
     for e in flatten(root, stopfunc):
         if targetfunc(e):
@@ -78,7 +97,7 @@ def find(root, targetfunc, stopfunc=None):
 # '/' for path separator, '#n' for index of duplicated names
 _quotenamere = re.compile(r'[%/#]')
 
-def _quotename(s):
+def _quotename(s: str) -> str:
     r"""Replace special characters to %xx (minimal set of urllib.quote)
 
     >>> _quotename('foo/bar%baz#qux')
@@ -88,7 +107,9 @@ def _quotename(s):
     """
     return _quotenamere.sub(lambda m: '%%%02X' % ord(m.group(0)), s)
 
-def _buildquotenamemap(items):
+def _buildquotenamemap(
+    items: Iterable["RepoTreeItem"]
+) -> Dict[str, List["RepoTreeItem"]]:
     namemap = {}
     for e in items:
         q = _quotename(e.shortname())
@@ -98,7 +119,7 @@ def _buildquotenamemap(items):
             namemap[q].append(e)
     return namemap
 
-def itempath(item):
+def itempath(item: "RepoTreeItem") -> str:
     """Virtual path to the given item"""
     rnames = []
     while item.parent():
@@ -112,7 +133,7 @@ def itempath(item):
         item = item.parent()
     return '/'.join(reversed(rnames))
 
-def findbyitempath(root, path):
+def findbyitempath(root: "RepoTreeItem", path: str) -> "RepoTreeItem":
     """Return the item for the given virtual path
 
     >>> root = RepoTreeItem()
@@ -175,40 +196,48 @@ def findbyitempath(root, path):
 class RepoTreeItem(object):
     xmltagname = 'treeitem'
 
-    def __init__(self, parent=None):
-        self._parent = parent
-        self.childs = []
+    def __init__(self, parent: Optional["RepoTreeItem"] = None) -> None:
+        self._parent: Optional["RepoTreeItem"] = parent
+        self.childs: List["RepoTreeItem"] = []
         self._row = 0
 
-    def appendChild(self, child):
+    def appendChild(self, child: "RepoTreeItem") -> None:
         child._row = len(self.childs)
         child._parent = self
         self.childs.append(child)
 
-    def insertChild(self, row, child):
+    def insertChild(self, row: int, child: "RepoTreeItem") -> None:
         child._row = row
         child._parent = self
         self.childs.insert(row, child)
 
-    def child(self, row):
+    def child(self, row: int) -> "RepoTreeItem":
         return self.childs[row]
 
-    def childCount(self):
+    def childCount(self) -> int:
         return len(self.childs)
 
-    def columnCount(self):
+    def childRoots(self) -> List[str]:
+        roots = []
+        if isinstance(self, RepoItem):
+            roots.append(self.rootpath())
+        for child in self.childs:
+            roots.extend(child.childRoots())
+        return roots
+
+    def columnCount(self) -> int:
         return 2
 
-    def data(self, column, role):
+    def data(self, column: int, role: Qt.ItemDataRole):
         return None
 
-    def setData(self, column, value):
+    def setData(self, column: int, value) -> bool:
         return False
 
-    def row(self):
+    def row(self) -> int:
         return self._row
 
-    def parent(self):
+    def parent(self) -> Optional["RepoTreeItem"]:
         return self._parent
 
     def menulist(self):
@@ -217,7 +246,7 @@ class RepoTreeItem(object):
     def flags(self):
         return Qt.ItemFlag.NoItemFlags
 
-    def removeRows(self, row, count):
+    def removeRows(self, row: int, count: int) -> bool:
         cs = self.childs
         remove = cs[row : row + count]
         keep = cs[:row] + cs[row + count:]
@@ -229,77 +258,92 @@ class RepoTreeItem(object):
             c._row = i
         return True
 
-    def dump(self, xw):
+    def dump(self, xw) -> None:
         _dumpChild(xw, parent=self)
 
     @classmethod
-    def undump(cls, xr):
+    def undump(cls: Type[_TRepoTreeItem], xr) -> _TRepoTreeItem:
         obj = cls()
         _undumpChild(xr, parent=obj)
         return obj
 
-    def dumpObject(self, xw):
+    def dumpObject(self, xw) -> None:
         xw.writeStartElement(self.xmltagname)
         self.dump(xw)
         xw.writeEndElement()
 
-    def isRepo(self):
+    def isRepo(self) -> bool:
         return False
 
-    def details(self):
+    def details(self) -> str:
         return ''
 
-    def okToDelete(self):
+    def okToDelete(self) -> bool:
         return True
 
     def getSupportedDragDropActions(self):
         return Qt.DropAction.MoveAction
 
+    def shortname(self) -> str:
+        return ''
+
+    def rootpath(self) -> str:
+        return ''
+
+    def getCommonPath(self) -> str:
+        return ''
+
 
 class RepoItem(RepoTreeItem):
     xmltagname = 'repo'
 
-    def __init__(self, root, shortname=None, basenode=None, sharedpath=None,
-                 parent=None):
+    def __init__(
+        self,
+        root: str,
+        shortname: Optional[str] = None,
+        basenode: Optional[bytes] = None,
+        sharedpath: Optional[str] = None,
+        parent: Optional[RepoTreeItem] = None
+    ) -> None:
         RepoTreeItem.__init__(self, parent)
         self._root = root
-        self._shortname = shortname or u''
-        self._basenode = basenode or node.nullid
+        self._shortname: str = shortname if shortname is not None else ''
+        self._basenode: bytes = basenode if basenode is not None else node.nullid
         # expensive check is done at appendSubrepos()
-        self._sharedpath = sharedpath or ''
+        self._sharedpath: str = sharedpath if sharedpath is not None else ''
         self._valid = True
 
-    def isRepo(self):
+    def isRepo(self) -> bool:
         return True
 
-    def rootpath(self):
+    def rootpath(self) -> str:
         return self._root
 
-    def shortname(self):
+    def shortname(self) -> str:
         if self._shortname:
             return self._shortname
         else:
             return os.path.basename(self._root)
 
-    def repotype(self):
+    def repotype(self) -> str:
         return 'hg'
 
-    def basenode(self):
+    def basenode(self) -> bytes:
         """Return node id of revision 0"""
         return self._basenode
 
-    def setBaseNode(self, basenode):
+    def setBaseNode(self, basenode: bytes) -> None:
         self._basenode = basenode
 
-    def setShortName(self, uname):
+    def setShortName(self, uname: str) -> None:
         uname = pycompat.unicode(uname)
         if uname != self._shortname:
             self._shortname = uname
 
-    def data(self, column, role):
+    def data(self, column: int, role: Qt.ItemDataRole):
         if role == Qt.ItemDataRole.DecorationRole and column == 0:
             baseiconname = 'hg'
-            if paths.is_unc_path(self.rootpath()):
+            if paths.is_unc_path(hglib.fromunicode(self.rootpath())):
                 baseiconname = 'thg-remote-repo'
             ico = qtlib.geticon(baseiconname)
             if not self._valid:
@@ -310,10 +354,10 @@ class RepoItem(RepoTreeItem):
         elif role in (Qt.ItemDataRole.DisplayRole, Qt.ItemDataRole.EditRole):
             return [self.shortname, self.shortpath][column]()
 
-    def getCommonPath(self):
+    def getCommonPath(self) -> str:
         return self.parent().getCommonPath()
 
-    def shortpath(self):
+    def shortpath(self) -> str:
         try:
             cpath = self.getCommonPath()
         except:
@@ -336,7 +380,7 @@ class RepoItem(RepoTreeItem):
         acts = ['open', 'clone', 'addsubrepo', None, 'explore',
                 'terminal', 'copypath', None, 'rename', 'remove']
         if self.childCount() > 0:
-            acts.extend([None, (_('&Sort'), ['sortbyname', 'sortbyhgsub'])])
+            acts.extend([None, 'openAll', (_('&Sort'), ['sortbyname', 'sortbyhgsub'])])
         acts.extend([None, 'settings'])
         return acts
 
@@ -344,7 +388,7 @@ class RepoItem(RepoTreeItem):
         return (Qt.ItemFlag.ItemIsEnabled | Qt.ItemFlag.ItemIsSelectable | Qt.ItemFlag.ItemIsDragEnabled
             | Qt.ItemFlag.ItemIsEditable)
 
-    def dump(self, xw):
+    def dump(self, xw) -> None:
         xw.writeAttribute('root', self._root)
         xw.writeAttribute('shortname', self.shortname())
         xw.writeAttribute('basenode',
@@ -354,21 +398,24 @@ class RepoItem(RepoTreeItem):
         _dumpChild(xw, parent=self)
 
     @classmethod
-    def undump(cls, xr):
+    def undump(cls: Type[_TRepoItem], xr) -> _TRepoItem:
         a = xr.attributes()
         obj = cls(pycompat.unicode(a.value('', 'root')),
                   pycompat.unicode(a.value('', 'shortname')),
-                  node.bin(str(a.value('', 'basenode'))),
+                  node.bin(pycompat.sysbytes(a.value('', 'basenode'))),
                   pycompat.unicode(a.value('', 'sharedpath')))
         _undumpChild(xr, parent=obj, undump=_undumpSubrepoItem)
         return obj
 
-    def details(self):
+    def details(self) -> str:
         return _('Local Repository %s') % self._root
 
-    def appendSubrepos(self, repo=None):
+    def appendSubrepos(
+        self,
+        repo: Optional[localrepo.localrepository] = None,
+    ) -> List[bytes]:
         self._sharedpath = ''
-        invalidRepoList = []
+        invalidRepoList: List[bytes] = []
         sri = None
         abssubpath = None
         try:
@@ -437,7 +484,7 @@ class RepoItem(RepoTreeItem):
                 'subrepos of:<br><br>"%s"<br><br>') +
                 _('The exception error message was:<br><br>%s<br><br>') +
                 _('Click OK to continue or Abort to exit.')) \
-                % (rootpath, hglib.tounicode(str(e)))
+                % (rootpath, hglib.exception_str(e))
             res = qtlib.WarningMsgBox(_('Error loading subrepos'),
                                 warningMessage,
                                 buttons = QMessageBox.StandardButton.Ok | QMessageBox.StandardButton.Abort)
@@ -446,7 +493,7 @@ class RepoItem(RepoTreeItem):
                 raise
         return invalidRepoList
 
-    def setData(self, column, value):
+    def setData(self, column: int, value) -> bool:
         if column == 0:
             shortname = hglib.fromunicode(value)
             abshgrcpath = os.path.join(hglib.fromunicode(self.rootpath()),
@@ -467,7 +514,7 @@ _subrepoType2IcoMap = {
     'svn': 'thg-svn-subrepo',
     }
 
-def _newSubrepoIcon(repotype, valid=True):
+def _newSubrepoIcon(repotype: str, valid: bool = True) -> QIcon:
     subiconame = _subrepoType2IcoMap.get(repotype)
     if subiconame is None:
         ico = qtlib.geticon('thg-subrepo')
@@ -482,7 +529,7 @@ class StandaloneSubrepoItem(RepoItem):
     """Mercurial repository just decorated as subrepo"""
     xmltagname = 'subrepo'
 
-    def data(self, column, role):
+    def data(self, column: int, role: Qt.ItemDataRole):
         if role == Qt.ItemDataRole.DecorationRole and column == 0:
             return _newSubrepoIcon('hg', valid=self._valid)
         else:
@@ -492,7 +539,7 @@ class SubrepoItem(RepoItem):
     """Actual Mercurial subrepo"""
     xmltagname = 'subrepo'
 
-    def data(self, column, role):
+    def data(self, column: int, role: Qt.ItemDataRole):
         if role == Qt.ItemDataRole.DecorationRole and column == 0:
             return _newSubrepoIcon('hg', valid=self._valid)
         else:
@@ -502,7 +549,7 @@ class SubrepoItem(RepoItem):
         acts = ['open', 'clone', None, 'addsubrepo', 'removesubrepo',
                 None, 'explore', 'terminal', 'copypath']
         if self.childCount() > 0:
-            acts.extend([None, (_('&Sort'), ['sortbyname', 'sortbyhgsub'])])
+            acts.extend([None, 'openAll', (_('&Sort'), ['sortbyname', 'sortbyhgsub'])])
         acts.extend([None, 'settings'])
         return acts
 
@@ -517,11 +564,13 @@ class AlienSubrepoItem(RepoItem):
     """Actual non-Mercurial subrepo"""
     xmltagname = 'subrepo'
 
-    def __init__(self, root, repotype, parent=None):
+    def __init__(
+        self, root: str, repotype: str, parent: Optional[RepoTreeItem] = None
+    ) -> None:
         RepoItem.__init__(self, root, parent=parent)
         self._repotype = repotype
 
-    def data(self, column, role):
+    def data(self, column: int, role: Qt.ItemDataRole):
         if role == Qt.ItemDataRole.DecorationRole and column == 0:
             return _newSubrepoIcon(self._repotype)
         else:
@@ -533,31 +582,36 @@ class AlienSubrepoItem(RepoItem):
     def flags(self):
         return Qt.ItemFlag.ItemIsEnabled | Qt.ItemFlag.ItemIsSelectable
 
-    def repotype(self):
+    def repotype(self) -> str:
         return self._repotype
 
-    def dump(self, xw):
+    def dump(self, xw) -> None:
         xw.writeAttribute('root', self._root)
         xw.writeAttribute('repotype', self._repotype)
 
     @classmethod
-    def undump(cls, xr):
+    def undump(cls: Type[_TAlienSubrepoItem], xr) -> _TAlienSubrepoItem:
         a = xr.attributes()
         obj = cls(pycompat.unicode(a.value('', 'root')),
                   str(a.value('', 'repotype')))
         xr.skipCurrentElement()  # no child
         return obj
 
-    def appendSubrepos(self, repo=None):
+    def appendSubrepos(
+        self,
+        repo: Optional[localrepo.localrepository] = None,
+    ) -> List[bytes]:
         raise Exception('unsupported by non-hg subrepo')
 
-def _newSubrepoItem(root, repotype):
+def _newSubrepoItem(
+    root: str, repotype: str
+) -> Union[AlienSubrepoItem, SubrepoItem]:
     if repotype == 'hg':
         return SubrepoItem(root)
     else:
         return AlienSubrepoItem(root, repotype=repotype)
 
-def _undumpSubrepoItem(xr):
+def _undumpSubrepoItem(xr) -> RepoItem:
     a = xr.attributes()
     repotype = str(a.value('', 'repotype')) or 'hg'
     if repotype == 'hg':
@@ -568,12 +622,14 @@ def _undumpSubrepoItem(xr):
 class RepoGroupItem(RepoTreeItem):
     xmltagname = 'group'
 
-    def __init__(self, name, parent=None):
+    def __init__(
+        self, name: str, parent: Optional[RepoTreeItem] = None
+    ) -> None:
         RepoTreeItem.__init__(self, parent)
         self.name = name
         self._commonpath = ''
 
-    def data(self, column, role):
+    def data(self, column: int, role: Qt.ItemDataRole):
         if role == Qt.ItemDataRole.DecorationRole:
             if column == 0:
                 s = QApplication.style()
@@ -586,16 +642,16 @@ class RepoGroupItem(RepoTreeItem):
             return self.getCommonPath()
         return None
 
-    def setData(self, column, value):
+    def setData(self, column: int, value) -> bool:
         if column == 0:
             self.name = pycompat.unicode(value)
             return True
         return False
 
-    def rootpath(self):  # for sortbypath()
+    def rootpath(self) -> str:  # for sortbypath()
         return ''  # may be okay to return _commonpath instead?
 
-    def shortname(self):  # for sortbyname()
+    def shortname(self) -> str:  # for sortbyname()
         return self.name
 
     def menulist(self):
@@ -607,24 +663,21 @@ class RepoGroupItem(RepoTreeItem):
         return (Qt.ItemFlag.ItemIsEnabled | Qt.ItemFlag.ItemIsSelectable | Qt.ItemFlag.ItemIsDropEnabled
             | Qt.ItemFlag.ItemIsDragEnabled | Qt.ItemFlag.ItemIsEditable)
 
-    def childRoots(self):
-        return [c._root for c in self.childs if isinstance(c, RepoItem)]
-
-    def dump(self, xw):
+    def dump(self, xw) -> None:
         xw.writeAttribute('name', self.name)
         _dumpChild(xw, parent=self)
 
     @classmethod
-    def undump(cls, xr):
+    def undump(cls: Type[_TRepoGroupItem], xr) -> _TRepoGroupItem:
         a = xr.attributes()
         obj = cls(pycompat.unicode(a.value('', 'name')))
         _undumpChild(xr, parent=obj)
         return obj
 
-    def okToDelete(self):
+    def okToDelete(self) -> bool:
         return False
 
-    def updateCommonPath(self, cpath=None):
+    def updateCommonPath(self, cpath: Optional[str] = None) -> None:
         """
         Update or set the group 'common path'
 
@@ -646,13 +699,15 @@ class RepoGroupItem(RepoTreeItem):
                       if not isinstance(child, RepoGroupItem)]
             self._commonpath = os.path.dirname(os.path.commonprefix(childs))
 
-    def getCommonPath(self):
+    def getCommonPath(self) -> str:
         return self._commonpath
 
 class AllRepoGroupItem(RepoGroupItem):
     xmltagname = 'allgroup'
 
-    def __init__(self, name=None, parent=None):
+    def __init__(
+        self, name: Optional[str]=None, parent: Optional[RepoTreeItem] = None
+    ) -> None:
         RepoGroupItem.__init__(self, name or _('default'), parent=parent)
 
     def menulist(self):
