@@ -5,10 +5,15 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import, print_function
+
 
 import os
 
+from typing import (
+    List,
+    Optional,
+)
+
 from .qtcore import (
     QAbstractItemModel,
     QByteArray,
@@ -55,18 +60,18 @@ def readXml(source, rootElementName):
     itemread = None
     xr = QXmlStreamReader(source)
     if xr.readNextStartElement():
-        ele = str(xr.name())
+        ele = xr.name()
         if ele != rootElementName:
             print("unexpected xml element '%s' "
                   "(was looking for %s)" % (ele, rootElementName))
             return
     if xr.hasError():
-        print(hglib.fromunicode(xr.errorString(), 'replace'))
+        print(xr.errorString())
     if xr.readNextStartElement():
         itemread = repotreeitem.undumpObject(xr)
         xr.skipCurrentElement()
     if xr.hasError():
-        print(hglib.fromunicode(xr.errorString(), 'replace'))
+        print(xr.errorString())
     return itemread
 
 def iterRepoItemFromXml(source):
@@ -109,7 +114,7 @@ class RepoTreeModel(QAbstractItemModel):
                 f.close()
 
         if not root:
-            root = repotreeitem.RepoTreeItem(self)
+            root = repotreeitem.RepoTreeItem()
         # due to issue #1075, 'all' may be missing even if 'root' exists
         try:
             all = repotreeitem.find(
@@ -319,7 +324,7 @@ class RepoTreeModel(QAbstractItemModel):
         else:
             return QModelIndex()
 
-    def repoRoot(self, index):
+    def repoRoot(self, index: QModelIndex) -> Optional[str]:
         item = index.internalPointer()
         if not isinstance(item, repotreeitem.RepoItem):
             return
@@ -340,11 +345,11 @@ class RepoTreeModel(QAbstractItemModel):
             item = self.rootItem
         return repotreeitem.itempath(item)
 
-    def indexFromItemPath(self, path, column=0):
+    def indexFromItemPath(self, path: str, column=0):
         """Model index for the item specified by the given virtual path"""
         try:
             item = repotreeitem.findbyitempath(self.rootItem,
-                                               pycompat.unicode(path))
+                                               path)
         except ValueError:
             return QModelIndex()
         return self._indexFromItem(item, column)
@@ -374,7 +379,7 @@ class RepoTreeModel(QAbstractItemModel):
         return self._indexFromItem(self._activeRepoItem, column)
 
     # TODO: rename loadSubrepos() and appendSubrepos() to scanRepo() ?
-    def loadSubrepos(self, index):
+    def loadSubrepos(self, index: QModelIndex) -> List[str]:
         """Scan subrepos of the repo; returns list of invalid paths"""
         item = index.internalPointer()
         if (not isinstance(item, repotreeitem.RepoItem)
@@ -396,7 +401,7 @@ class RepoTreeModel(QAbstractItemModel):
             item._sharedpath = tmpitem._sharedpath
             item._valid = tmpitem._valid
             self._emitItemDataChanged(item)
-        return pycompat.maplist(hglib.tounicode, invalidpaths)
+        return hglib.to_unicode_list(invalidpaths)
 
     def updateCommonPaths(self, showShortPaths=None):
         if showShortPaths is not None:
@@ -409,8 +414,7 @@ class RepoTreeModel(QAbstractItemModel):
                     grp.updateCommonPath('')
 
     @pyqtSlot(str)
-    def _updateShortName(self, uroot):
-        uroot = pycompat.unicode(uroot)
+    def _updateShortName(self, uroot: str):
         repoagent = self._repomanager.repoAgent(uroot)
         it = self.getRepoItem(uroot)
         if it:
@@ -418,8 +422,7 @@ class RepoTreeModel(QAbstractItemModel):
             self._emitItemDataChanged(it)
 
     @pyqtSlot(str)
-    def _updateBaseNode(self, uroot):
-        uroot = pycompat.unicode(uroot)
+    def _updateBaseNode(self, uroot: str):
         repo = self._repomanager.repoAgent(uroot).rawRepo()
         it = self.getRepoItem(uroot)
         if it:
