@@ -15,7 +15,7 @@
 # this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-from __future__ import absolute_import
+
 
 from math import sin, cos, pi
 
@@ -48,6 +48,7 @@ from .qtgui import (
     QListWidget,
     QListWidgetItem,
     QMenu,
+    QMouseEvent,
     QPainter,
     QPainterPath,
     QPen,
@@ -137,7 +138,7 @@ class HgRepoView(QTableView):
     def repo(self):
         return self._repoagent.rawRepo()
 
-    def mousePressEvent(self, event):
+    def mousePressEvent(self, event: QMouseEvent) -> None:
         index = self.indexAt(event.pos())
         if not index.isValid():
             return
@@ -161,13 +162,13 @@ class HgRepoView(QTableView):
 
     @pyqtSlot(QPoint)
     def headerMenuRequest(self, point):
-        self.headermenu.exec_(self.horizontalHeader().mapToGlobal(point))
+        self.headermenu.exec(self.horizontalHeader().mapToGlobal(point))
 
     def setHistoryColumns(self):
         dlg = ColumnSelectDialog(self.colselect[1],
                                  self.model(), self.visibleColumns())
         dlg.setRowHeight(self.defaultRowHeight())
-        if dlg.exec_() == QDialog.DialogCode.Accepted:
+        if dlg.exec() == QDialog.DialogCode.Accepted:
             self.setVisibleColumns(dlg.selectedColumns())
             self.resizeColumns()
             self.setDefaultRowHeight(dlg.rowHeight())
@@ -304,7 +305,7 @@ class HgRepoView(QTableView):
             if isinstance(w, int):
                 pass
             elif w is not None:
-                w = fontm.horizontalAdvance(hglib.tounicode(str(w)) + 'w')
+                w = fontm.horizontalAdvance(str(w) + 'w')
             else:
                 w = super(HgRepoView, self).sizeHintForColumn(c)
             self.setColumnWidth(c, w)
@@ -441,12 +442,10 @@ class HgRepoView(QTableView):
         try:
             rev = self._symbolic_rev_to_numeric_rev(rev)
         except error.FilteredRepoLookupError:
-            self.showMessage.emit(_("Revision '%s' is hidden")
-                                  % hglib.tounicode(str(rev)))
+            self.showMessage.emit(_("Revision '%s' is hidden") % str(rev))
             return
         except error.RepoError:
-            self.showMessage.emit(_("Can't find revision '%s'")
-                                  % hglib.tounicode(str(rev)))
+            self.showMessage.emit(_("Can't find revision '%s'") % str(rev))
             return
         # When Mercurial is not able to disambiguate commit hash prefixes,
         # it raises an error.AmbiguousPrefixLookupError, which ultimately
@@ -456,7 +455,7 @@ class HgRepoView(QTableView):
         #
         # We cannot narrow this clause until hg-git is updated.
         except error.LookupError as e:
-            self.showMessage.emit(hglib.tounicode(str(e)))
+            self.showMessage.emit(hglib.exception_str(e))
             return
 
         model = self.model()
