@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import os
 
@@ -62,6 +62,9 @@ if hglib.TYPE_CHECKING:
     from .qtgui import (
         QWidget,
     )
+    from ..util.typelib import (
+        Qt_ItemFlags,
+    )
 
 MARGINS = (8, 0, 0, 0)
 
@@ -347,7 +350,7 @@ class ResolveDialog(QDialog):
             dlg = visdiff.visual_diff(self.repo.ui, self.repo, paths, p1, p2,
                                       self.repo[None], self.tcombo.readValue())
             if dlg:
-                dlg.exec_()
+                dlg.exec()
 
     def vp0(self):
         paths = self.getVdiffFiles(self.rtree)
@@ -356,7 +359,7 @@ class ResolveDialog(QDialog):
             dlg = visdiff.visual_diff(self.repo.ui, self.repo, paths, p1, None,
                                       self.repo[None], self.tcombo.readValue())
             if dlg:
-                dlg.exec_()
+                dlg.exec()
 
     def vp1(self):
         paths = self.getVdiffFiles(self.rtree)
@@ -365,7 +368,7 @@ class ResolveDialog(QDialog):
             dlg = visdiff.visual_diff(self.repo.ui, self.repo, paths, p2, None,
                                       self.repo[None], self.tcombo.readValue())
             if dlg:
-                dlg.exec_()
+                dlg.exec()
 
     def diffLocToAnc(self):
         paths = self.getVdiffFiles(self.utree)
@@ -377,7 +380,7 @@ class ResolveDialog(QDialog):
                     'tool': self.tcombo.readValue()}
             dlg = visdiff.visualdiff(self.repo.ui, self.repo, paths, opts)
             if dlg:
-                dlg.exec_()
+                dlg.exec()
 
     def diffOthToAnc(self):
         paths = self.getVdiffFiles(self.utree)
@@ -389,7 +392,7 @@ class ResolveDialog(QDialog):
                     'tool': self.tcombo.readValue()}
             dlg = visdiff.visualdiff(self.repo.ui, self.repo, paths, opts)
             if dlg:
-                dlg.exec_()
+                dlg.exec()
 
     @pyqtSlot()
     def refresh(self):
@@ -532,7 +535,7 @@ class PathsModel(QAbstractTableModel):
         return None
 
     def flags(self, index):
-        # type: (QModelIndex) -> Qt.ItemFlags
+        # type: (QModelIndex) -> Qt_ItemFlags
         flags = super(PathsModel, self).flags(index)
         if not index.isValid():
             return flags
