@@ -6,7 +6,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import os
 
@@ -69,7 +69,7 @@ _fileactionsbytype = {
                 'copyRelativePath', None,
                 'revertFile'],
     'file': ['visualDiffFile', 'visualDiffFileToLocal', None, 'editFile',
-             'saveFile', None, 'editLocalFile', 'openLocalFile',
+             'openFile', 'saveFile', None, 'editLocalFile', 'openLocalFile',
              'exploreLocalFile', 'copyPath', 'copyRelativePath', None,
              'revertFile', None,
              'navigateFileLog', 'navigateFileDiff', 'filterFile'],
@@ -112,7 +112,7 @@ class RevDetailsWidget(QWidget, qtlib.TaskWidget):
         return self._repoagent.rawRepo()
 
     def setupUi(self):
-        self.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.Expanding)
+        self.setSizePolicy(QSizePolicy.Policy.Preferred, QSizePolicy.Policy.Expanding)
 
         # + basevbox -------------------------------------------------------+
         # |+ filelistsplit ........                                         |
@@ -133,13 +133,13 @@ class RevDetailsWidget(QWidget, qtlib.TaskWidget):
         basevbox.addWidget(self.filelistsplit)
 
         self.splitternames.append('filelistsplit')
-        self.filelistsplit.setOrientation(Qt.Horizontal)
+        self.filelistsplit.setOrientation(Qt.Orientation.Horizontal)
         self.filelistsplit.setChildrenCollapsible(False)
 
         self.filelisttbar = QToolBar(_('File List Toolbar'))
         self.filelisttbar.setIconSize(qtlib.smallIconSize())
         self.filelist = HgFileListView(self)
-        self.filelist.setContextMenuPolicy(Qt.CustomContextMenu)
+        self.filelist.setContextMenuPolicy(Qt.ContextMenuPolicy.CustomContextMenu)
         self.filelist.customContextMenuRequested.connect(self.menuRequest)
         self.filelist.doubleClicked.connect(self.onDoubleClick)
         self._filelistpaletteswitcher = qtlib.PaletteSwitcher(self.filelist)
@@ -158,7 +158,7 @@ class RevDetailsWidget(QWidget, qtlib.TaskWidget):
 
         vbox = QVBoxLayout(self.fileviewframe)
         vbox.setSpacing(0)
-        vbox.setSizeConstraint(QLayout.SetDefaultConstraint)
+        vbox.setSizeConstraint(QLayout.SizeConstraint.SetDefaultConstraint)
         vbox.setContentsMargins(0, 0, 0, 0)
         panelframevbox = vbox
 
@@ -167,16 +167,16 @@ class RevDetailsWidget(QWidget, qtlib.TaskWidget):
             self.messagesplitter.setStyle(QStyleFactory.create('Plastique'))
 
         self.splitternames.append('messagesplitter')
-        self.messagesplitter.setSizePolicy(QSizePolicy.Preferred,
-                                           QSizePolicy.Expanding)
+        self.messagesplitter.setSizePolicy(QSizePolicy.Policy.Preferred,
+                                           QSizePolicy.Policy.Expanding)
         self.messagesplitter.setMinimumSize(QSize(50, 50))
-        self.messagesplitter.setFrameShape(QFrame.NoFrame)
+        self.messagesplitter.setFrameShape(QFrame.Shape.NoFrame)
         self.messagesplitter.setLineWidth(0)
         self.messagesplitter.setMidLineWidth(0)
-        self.messagesplitter.setOrientation(Qt.Vertical)
+        self.messagesplitter.setOrientation(Qt.Orientation.Vertical)
         self.messagesplitter.setOpaqueResize(True)
         self.message = QTextBrowser(self.messagesplitter,
-                                    lineWrapMode=QTextEdit.NoWrap,
+                                    lineWrapMode=QTextEdit.LineWrapMode.NoWrap,
                                     openLinks=False)
         self.message.minimumSizeHint = lambda: QSize(0, 25)
         self.message.anchorClicked.connect(self._forwardAnchorClicked)
@@ -277,7 +277,7 @@ class RevDetailsWidget(QWidget, qtlib.TaskWidget):
         m = QMenu(w)
         m.addActions(self._parentToggleGroup.actions())
         w.setMenu(m)
-        w.setPopupMode(QToolButton.MenuButtonPopup)
+        w.setPopupMode(QToolButton.ToolButtonPopupMode.MenuButtonPopup)
         self._actionParentToggle = a = tbar.addWidget(w)
         a.setIcon(qtlib.geticon('hg-merged-both'))
         a.setToolTip(_('Toggle parent to be used as the base revision'))
@@ -292,12 +292,12 @@ class RevDetailsWidget(QWidget, qtlib.TaskWidget):
     def eventFilter(self, watched, event):
         # switch between filter and list seamlessly
         if watched is self.filefilter:
-            if event.type() == QEvent.KeyPress and event.key() == Qt.Key_Down:
+            if event.type() == QEvent.Type.KeyPress and event.key() == Qt.Key.Key_Down:
                 self.filelist.setFocus()
                 return True
             return False
         elif watched is self.filelist:
-            if event.type() == QEvent.KeyPress and event.key() == Qt.Key_Up:
+            if event.type() == QEvent.Type.KeyPress and event.key() == Qt.Key.Key_Up:
                 index = self.filelist.currentIndex()
                 if index.row() == 0 and not index.parent().isValid():
                     self.filefilter.setFocus()
@@ -437,7 +437,7 @@ class RevDetailsWidget(QWidget, qtlib.TaskWidget):
         m.addSeparator()
         m.addAction(self._actionFlatFileList)
 
-        contextmenu.setAttribute(Qt.WA_DeleteOnClose)
+        contextmenu.setAttribute(Qt.WidgetAttribute.WA_DeleteOnClose)
         contextmenu.popup(self.filelist.viewport().mapToGlobal(point))
 
     def _setupFileMenu(self, contextmenu):
@@ -513,9 +513,9 @@ class RevDetailsWidget(QWidget, qtlib.TaskWidget):
         model.setFlat(flat)
         view.setRootIsDecorated(not flat)
         if flat:
-            view.setTextElideMode(Qt.ElideLeft)
+            view.setTextElideMode(Qt.TextElideMode.ElideLeft)
         else:
-            view.setTextElideMode(Qt.ElideRight)
+            view.setTextElideMode(Qt.TextElideMode.ElideRight)
         self._expandShortFileList()
 
     def fileStatusFilter(self):
@@ -559,9 +559,9 @@ class RevDetailsWidget(QWidget, qtlib.TaskWidget):
 class RevDetailsDialog(QDialog):
     'Standalone revision details tool, a wrapper for RevDetailsWidget'
 
-    def __init__(self, repoagent, rev='.', parent=None):
+    def __init__(self, repoagent, rev=b'.', parent=None):
         QDialog.__init__(self, parent)
-        self.setWindowFlags(Qt.Window)
+        self.setWindowFlags(Qt.WindowType.Window)
         self.setWindowIcon(qtlib.geticon('hg-log'))
         self._repoagent = repoagent
 
@@ -589,7 +589,7 @@ class RevDetailsDialog(QDialog):
 
         self.revdetails = revdetails
         self.setRev(rev)
-        qtlib.newshortcutsforstdkey(QKeySequence.Refresh, self, self.refresh)
+        qtlib.newshortcutsforstdkey(QKeySequence.StandardKey.Refresh, self, self.refresh)
 
     def setRev(self, rev):
         self.revdetails.onRevisionSelected(rev)
@@ -660,7 +660,7 @@ class RevDetailsDialog(QDialog):
             revstr = _('Working Directory')
         else:
             hash = self.revdetails.ctx.hex()[:12]
-            revstr = '@%s: %s' % (str(revnum), hash)
+            revstr = '@%s: %s' % (str(revnum), hglib.tounicode(hash))
         self.setWindowTitle(_('%s - Revision Details (%s)')
                             % (self._repoagent.displayName(), revstr))
         self.revdetails.reload()
