@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import os
 
@@ -539,8 +539,7 @@ class StatusWidget(QWidget):
             self._fileactions.editLocalFile()
 
     @pyqtSlot(str)
-    def setStatusFilter(self, status):
-        status = str(status)
+    def setStatusFilter(self, status: str) -> None:
         for s in statusTypes:
             val = statusTypes[s]
             self.opts[val.name] = s in status
@@ -760,16 +759,11 @@ class StatusThread(QThread):
                 if wctx.sub(s).dirty():
                     wctx.dirtySubrepos.append(s)
         except EnvironmentError as e:
-            self.showMessage.emit(hglib.tounicode(str(e)))
+            self.showMessage.emit(hglib.exception_str(e))
         except (error.LookupError, error.RepoError, error.ConfigError) as e:
-            self.showMessage.emit(hglib.tounicode(str(e)))
+            self.showMessage.emit(hglib.exception_str(e))
         except error.Abort as e:
-            if e.hint:
-                err = _('%s (hint: %s)') % (hglib.tounicode(str(e)),
-                                            hglib.tounicode(e.hint))
-            else:
-                err = hglib.tounicode(str(e))
-            self.showMessage.emit(err)
+            self.showMessage.emit(hglib.exception_str(e, show_hint=True))
 
 
 class WctxFileTree(QTreeView):
@@ -796,7 +790,7 @@ class WctxModel(QAbstractTableModel):
         rows = []
         nchecked = {}
         excludestr = opts.get('ciexclude', '')
-        assert isinstance(excludestr, (str, pycompat.unicode))
+        assert isinstance(excludestr, str)
         excludes = [f.strip() for f in excludestr.split(',')]
         if amending is None:
             amending = set()
@@ -952,6 +946,8 @@ class WctxModel(QAbstractTableModel):
             return False
         if (index.column() == COL_PATH and role == Qt.ItemDataRole.CheckStateRole
             and self.checkable):
+            value = qtlib.toCheckStateEnum(value)
+
             if self.data(index, role) == value:
                 return True
             if value not in (Qt.CheckState.Checked, Qt.CheckState.Unchecked):
@@ -1102,12 +1098,12 @@ class WctxModel(QAbstractTableModel):
         self.layoutChanged.emit()
         self.endResetModel()
 
-    def setFilter(self, match):
+    def setFilter(self, match: str):
         'simple match in filename filter'
         self.layoutAboutToBeChanged.emit()
         self.beginResetModel()
         self.rows = [r for r in self.unfiltered
-                     if pycompat.unicode(match) in r[COL_PATH_DISPLAY]]
+                     if match in r[COL_PATH_DISPLAY]]
         self.layoutChanged.emit()
         self.endResetModel()
 
@@ -1248,8 +1244,7 @@ class StatusDialog(QDialog):
                                     self.stwidget.refreshWctx)
         QTimer.singleShot(0, self.stwidget.refreshWctx)
 
-    def linkActivated(self, link):
-        link = pycompat.unicode(link)
+    def linkActivated(self, link: str):
         if link.startswith('repo:'):
             self._subdialogs.open(link[len('repo:'):])
 
