@@ -6,7 +6,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import os
 import re
@@ -99,14 +99,14 @@ if hglib.TYPE_CHECKING:
 
 
 def parseurl(url):
-    # _type: (pycompat.unicode) -> urlutil.url
+    # _type: (str) -> urlutil.url
     # TODO: re-enable this after dropping 5.7 support
-    assert isinstance(url, pycompat.unicode), repr(url)
+    assert isinstance(url, str), repr(url)
     return urlutil.url(hglib.fromunicode(url))
 
 def linkify(url):
-    # type: (pycompat.unicode) -> pycompat.unicode
-    assert isinstance(url, pycompat.unicode), repr(url)
+    # type: (str) -> str
+    assert isinstance(url, str), repr(url)
     u = urlutil.url(hglib.fromunicode(url))
     if u.scheme in (b'http', b'https'):
         safe = urlutil.hidepassword(hglib.fromunicode(url))
@@ -142,7 +142,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         self._repoagent = repoagent
         self._cmdsession = cmdcore.nullCmdSession()
         # peer repository of last command
-        self._lasturl = None  # type: Optional[pycompat.unicode]
+        self._lasturl = None  # type: Optional[str]
         self._lastbfile = None  # output bundle of last incoming command
         self.opts = {}  # type: Dict[str, Union[bool, bytes]]
         self.cmenu = None
@@ -377,7 +377,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         dlg = OptionsDialog(self._repoagent, self.opts, self)
         dlg.setWindowFlags(Qt.WindowType.Sheet)
         dlg.setWindowModality(Qt.WindowModality.WindowModal)
-        if dlg.exec_() == QDialog.DialogCode.Accepted:
+        if dlg.exec() == QDialog.DialogCode.Accepted:
             self.opts.update(dlg.outopts)
             self.refreshUrl()
 
@@ -449,8 +449,8 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         sm.currentRowChanged.connect(self.pathSelected)
 
     def currentUrl(self):
-        # type: () -> pycompat.unicode
-        return pycompat.unicode(self.urlentry.text())
+        # type: () -> str
+        return self.urlentry.text()
 
     def urlChanged(self):
         self.securebutton.setEnabled('https://' in self.currentUrl())
@@ -477,13 +477,13 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         self.setEditUrl(hglib.tounicode(path))
 
     def setEditUrl(self, newurl):
-        # type: (pycompat.unicode) -> None
+        # type: (str) -> None
         'Set the current URL without changing the alias [unicode]'
         self.urlentry.setText(newurl)
         self.refreshUrl()
 
     def setUrl(self, newurl):
-        # type: (pycompat.unicode) -> None
+        # type: (str) -> None
         'Set the current URL to the given alias or URL [unicode]'
         model = self.hgrctv.model()
         assert model is not None
@@ -512,11 +512,11 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
     def dropEvent(self, event):
         data = event.mimeData()
         if data.hasUrls():
-            url = pycompat.unicode(data.urls()[0].toString())
+            url = data.urls()[0].toString()
             event.setDropAction(Qt.DropAction.CopyAction)
             event.accept()
         elif data.hasText():
-            url = pycompat.unicode(data.text())
+            url = data.text()
             event.setDropAction(Qt.DropAction.CopyAction)
             event.accept()
         else:
@@ -559,10 +559,10 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         self.menualias = alias
         for act in self.acts[-2:]:
             act.setEnabled(editable)
-        self.cmenu.exec_(point)
+        self.cmenu.exec(point)
 
     def exploreurl(self):
-        url = pycompat.unicode(self.menuurl)
+        url = self.menuurl
         u = parseurl(url)
         if not u.scheme or u.scheme == b'file':
             qtlib.openlocalurl(u.path)
@@ -570,7 +570,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
             QDesktopServices.openUrl(QUrl(url))
 
     def terminalurl(self):
-        url = pycompat.unicode(self.menuurl)
+        url = self.menuurl
         u = parseurl(url)
         if u.scheme and u.scheme != b'file':
             qtlib.InfoMsgBox(_('Repository not local'),
@@ -580,11 +580,11 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
 
     def editurl(self):
         alias = hglib.fromunicode(self.menualias)
-        urlu = pycompat.unicode(self.menuurl)
+        urlu = self.menuurl
         dlg = SaveDialog(self._repoagent, alias, urlu, self, edit=True)
         dlg.setWindowFlags(Qt.WindowType.Sheet)
         dlg.setWindowModality(Qt.WindowModality.WindowModal)
-        if dlg.exec_() == QDialog.DialogCode.Accepted:
+        if dlg.exec() == QDialog.DialogCode.Accepted:
             self.curalias = hglib.fromunicode(dlg.aliasentry.text())
             self.setEditUrl(dlg.urlentry.text())
             self.reload()
@@ -620,7 +620,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         dlg = SaveDialog(self._repoagent, alias, self.currentUrl(), self)
         dlg.setWindowFlags(Qt.WindowType.Sheet)
         dlg.setWindowModality(Qt.WindowModality.WindowModal)
-        if dlg.exec_() == QDialog.DialogCode.Accepted:
+        if dlg.exec() == QDialog.DialogCode.Accepted:
             self.curalias = hglib.fromunicode(dlg.aliasentry.text())
             self.reload()
 
@@ -641,7 +641,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         dlg = SecureDialog(self._repoagent, self.currentUrl(), self)
         dlg.setWindowFlags(Qt.WindowType.Sheet)
         dlg.setWindowModality(Qt.WindowModality.WindowModal)
-        dlg.exec_()
+        dlg.exec()
 
     @pyqtSlot()
     def _updateUi(self):
@@ -753,7 +753,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
             self.pushclicked(confirm, **kwargs)
 
     def pullBundle(self, bundle, rev, bsource=None):
-        # type: (pycompat.unicode, Optional[bytes], Optional[pycompat.unicode]) -> None
+        # type: (str, Optional[bytes], Optional[str]) -> None
         'accept bundle changesets'
         if not self._cmdsession.isFinished():
             self.showMessage.emit(_('sync command already running'))
@@ -775,7 +775,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
     ##
 
     def linkifyWithTarget(self, url):
-        # type: (pycompat.unicode) -> pycompat.unicode
+        # type: (str) -> str
         link = linkify(url)
         if self.targetcheckbox.isChecked():
             link += u" (%s)" % self.targetcombo.currentText()
@@ -822,7 +822,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
                                   % (link, ret))
 
     def pullclicked(self, url=None):
-        # type: (Optional[pycompat.unicode]) -> None
+        # type: (Optional[str]) -> None
         link = self.linkifyWithTarget(url or self.currentUrl())
 
         cmdline = ['pull', '--verbose']
@@ -860,7 +860,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         if self.cachedpp in ('rebase', 'updateorrebase'):
             if os.path.exists(self.repo.vfs.join(b'rebasestate')):
                 dlg = rebase.RebaseDialog(self._repoagent, self)
-                dlg.exec_()
+                dlg.exec()
                 return
         # handle file conflicts during update
         for root, path, status in thgrepo.recursiveMergeStatus(self.repo):
@@ -868,7 +868,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
                 qtlib.InfoMsgBox(_('Merge caused file conflicts'),
                                 _('File conflicts need to be resolved'))
                 dlg = resolve.ResolveDialog(self._repoagent, self)
-                dlg.exec_()
+                dlg.exec()
                 return
 
     def outclicked(self):
@@ -936,7 +936,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
             p4url = hglib.fromunicode(self._lasturl)
             dlg = PerforcePending(self._repoagent, pending, p4url, self)
             dlg.showMessage.connect(self.showMessage)
-            dlg.exec_()
+            dlg.exec()
 
     def pushclicked(self, confirm, rev=None, branch=None, pushall=False):
         if confirm is None:
@@ -1038,7 +1038,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
         dlg = PostPullDialog(self._repoagent, self)
         dlg.setWindowFlags(Qt.WindowType.Sheet)
         dlg.setWindowModality(Qt.WindowModality.WindowModal)
-        dlg.exec_()
+        dlg.exec()
 
     def emailclicked(self):
         cmdline = ['outgoing', '--template', '{node}\n']
@@ -1050,7 +1050,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
     def syncBookmark(self):
         dlg = bookmark.SyncBookmarkDialog(self._repoagent, self.currentUrl(),
                                           self)
-        dlg.exec_()
+        dlg.exec()
 
     @pyqtSlot(int)
     def _onOutgoingEmailFinished(self, ret):
@@ -1105,7 +1105,7 @@ class SyncWidget(QWidget, qtlib.TaskWidget):
             self._repoagent.pollStatus()
         except EnvironmentError as e:
             qtlib.WarningMsgBox(_('Unable to write configuration file'),
-                                hglib.tounicode(str(e)), parent=self)
+                                hglib.exception_str(e), parent=self)
         self.reload()
 
 
@@ -1180,12 +1180,12 @@ class PostPullDialog(QDialog):
         return self._repoagent.rawRepo()
 
     def linkactivated(self, command):
-        # type: (pycompat.unicode) -> None
+        # type: (str) -> None
         if command == 'config':
             from tortoisehg.hgqt.settings import SettingsDialog
             sd = SettingsDialog(configrepo=False, focus='tortoisehg.postpull',
                             parent=self, root=self.repo.root)
-            sd.exec_()
+            sd.exec()
 
     def getValue(self):
         # type: () -> str
@@ -1210,7 +1210,7 @@ class PostPullDialog(QDialog):
             self._repoagent.pollStatus()
         except EnvironmentError as e:
             qtlib.WarningMsgBox(_('Unable to write configuration file'),
-                                hglib.tounicode(str(e)), parent=self)
+                                hglib.exception_str(e), parent=self)
         super(PostPullDialog, self).accept()
 
 
@@ -1299,7 +1299,7 @@ class SaveDialog(QDialog):
             wconfig.writefile(cfg, fn)
         except EnvironmentError as e:
             qtlib.WarningMsgBox(_('Unable to write configuration file'),
-                                hglib.tounicode(str(e)), parent=self)
+                                hglib.exception_str(e), parent=self)
         if self.updatesubpaths.isChecked():
             ctx = repo[b'.']
             for subname in ctx.substate:  # type: bytes
@@ -1368,7 +1368,7 @@ def _addBrowseButton(edit, slot):
 
 class SecureDialog(QDialog):
     def __init__(self, repoagent, urlu, parent):
-        # type: (thgrepo.RepoAgent, pycompat.unicode, QWidget) -> None
+        # type: (thgrepo.RepoAgent, str, QWidget) -> None
         super(SecureDialog, self).__init__(parent)
         self._repoagent = repoagent
         self._querysess = cmdcore.nullCmdSession()
@@ -1597,7 +1597,7 @@ are expanded in the filename.'''))
             self._repoagent.pollStatus()
         except EnvironmentError as e:
             qtlib.WarningMsgBox(_('Unable to write configuration file'),
-                                hglib.tounicode(str(e)), parent=self)
+                                hglib.exception_str(e), parent=self)
         super(SecureDialog, self).accept()
 
     @pyqtSlot()
