@@ -8,7 +8,7 @@
 # See mercurial/extensions.py, comments to wrapfunction, for this approach
 # to extending repositories and change contexts.
 
-from __future__ import absolute_import
+
 
 import os
 import sys
@@ -48,6 +48,7 @@ from ..util.patchctx import patchctx
 from . import (
     cmdcore,
     hgconfig,
+    qtlib,
 )
 
 if hglib.TYPE_CHECKING:
@@ -700,7 +701,7 @@ class RepoManager(QObject):
         for _sig, slot in self._SIGNALMAP:
             mapper = QSignalMapper(self)
             self._sigmappers.append(mapper)
-            mapper.mapped[str].connect(getattr(self, slot))
+            qtlib.getMappedStringSignal(mapper).connect(getattr(self, slot))
 
     def openRepoAgent(self, path):
         """Return RepoAgent for the specified path and increment refcount"""
