@@ -5,9 +5,6 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
-
-from mercurial import error
 
 from .qtcore import (
     Qt,
@@ -27,10 +24,6 @@ from .qtgui import (
     QWidget,
 )
 
-from mercurial import (
-    pycompat,
-)
-
 from ..util import hglib
 from ..util.obsoleteutil import first_known_successors
 from ..util.i18n import _
@@ -180,7 +173,7 @@ class TopicDialog(QDialog):
 
     @pyqtSlot()
     def set_topic(self):
-        topic = pycompat.unicode(self.topicsCombo.currentText())
+        topic = self.topicsCombo.currentText()
         finishmsg = _("Set topic to '%s'") % topic
         self._runTopic(topic, rev=self.rev, finishmsg=finishmsg)
 
