@@ -7,7 +7,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 from .qtcore import (
     pyqtSlot,
@@ -389,7 +389,7 @@ class UpdateWidget(cmdui.AbstractCmdWidget):
                     buttonnames[btn] = name
                 dlg.setDefaultButton(QMessageBox.StandardButton.Cancel)
                 dlg.setText(msg)
-                dlg.exec_()
+                dlg.exec()
                 return buttonnames.get(dlg.clickedButton())
 
             # If merge-by-default, we want to merge whenever possible,
@@ -406,7 +406,7 @@ class UpdateWidget(cmdui.AbstractCmdWidget):
                     from tortoisehg.hgqt import shelve
                     dlg = shelve.ShelveDialog(self._repoagent, self)
                     dlg.finished.connect(dlg.deleteLater)
-                    dlg.exec_()
+                    dlg.exec()
                     return cmdcore.nullCmdSession()
                 elif clicked == 'merge':
                     cmdline.append('--merge')
@@ -453,6 +453,6 @@ class UpdateDialog(cmdui.CmdControlDialog):
         qtlib.InfoMsgBox(_('Merge caused file conflicts'),
                          _('File conflicts need to be resolved'))
         dlg = resolve.ResolveDialog(self._repoagent, self)
-        dlg.exec_()
+        dlg.exec()
         if not self.isLogVisible():
             self.reject()
