@@ -80,7 +80,7 @@ if hglib.TYPE_CHECKING:
 
 
 # Match parent2 first, so 'parent1?' will match both parent1 and parent
-_regex = b'\$(parent2|parent1?|child|plabel1|plabel2|clabel|repo|phash1|phash2|chash)'
+_regex = rb'\$(parent2|parent1?|child|plabel1|plabel2|clabel|repo|phash1|phash2|chash)'
 
 _nonexistant = _('[non-existant]')
 
