@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 from .qtcore import (
     QObject,
@@ -110,9 +110,8 @@ class WctxCleaner(QObject):
         self.checkFinished.emit(not dirty, parents)
 
     @pyqtSlot(str)
-    def runCleaner(self, cmd):
+    def runCleaner(self, cmd: str) -> None:
         """Clean working directory by the specified action"""
-        cmd = str(cmd)
         if cmd == 'commit':
             self.launchCommitDialog()
         elif cmd == 'shelve':
@@ -127,20 +126,20 @@ class WctxCleaner(QObject):
         from tortoisehg.hgqt import commit
         dlg = commit.CommitDialog(self._repoagent, [], {}, self.parent())
         dlg.finished.connect(dlg.deleteLater)
-        dlg.exec_()
+        dlg.exec()
         self.check()
 
     def launchShelveDialog(self):
         from tortoisehg.hgqt import shelve
         dlg = shelve.ShelveDialog(self._repoagent, self.parent())
         dlg.finished.connect(dlg.deleteLater)
-        dlg.exec_()
+        dlg.exec()
         self.check()
 
     def discardChanges(self, confirm=True):
         if confirm:
-            labels = [(QMessageBox.Yes, _('&Discard')),
-                      (QMessageBox.No, _('Cancel'))]
+            labels = [(QMessageBox.StandardButton.Yes, _('&Discard')),
+                      (QMessageBox.StandardButton.No, _('Cancel'))]
             if not qtlib.QuestionMsgBox(_('Confirm Discard'),
                      _('Discard outstanding changes to working directory?'),
                      labels=labels, parent=self.parent()):
