@@ -9,7 +9,7 @@
 Main Qt4 application for TortoiseHg
 """
 
-from __future__ import absolute_import
+
 
 import os
 import subprocess
@@ -728,9 +728,8 @@ class Workbench(QMainWindow):
         self._updateShowConsoleAction()
 
     @pyqtSlot(str, bool)
-    def openRepo(self, root, reuse, bundle=None):
+    def openRepo(self, root: str, reuse: bool, bundle=None):
         """Open tab of the specified repo [unicode]"""
-        root = pycompat.unicode(root)
         if not root or root.startswith('ssh://'):
             return
         if reuse and self.repoTabsWidget.selectRepo(root):
@@ -752,7 +751,7 @@ class Workbench(QMainWindow):
     def dragEnterEvent(self, event):
         d = event.mimeData()
         for u in d.urls():
-            root = paths.find_root(pycompat.unicode(u.toLocalFile()))
+            root = paths.find_root(u.toLocalFile())
             if root:
                 event.setDropAction(Qt.DropAction.LinkAction)
                 event.accept()
@@ -762,7 +761,7 @@ class Workbench(QMainWindow):
         accept = False
         d = event.mimeData()
         for u in d.urls():
-            root = paths.find_root(pycompat.unicode(u.toLocalFile()))
+            root = paths.find_root(u.toLocalFile())
             if root:
                 self.showRepo(root)
                 accept = True
@@ -843,8 +842,7 @@ class Workbench(QMainWindow):
         self._updateWindowTitle()
 
     @pyqtSlot(str)
-    def _onCurrentRepoChanged(self, curpath):
-        curpath = pycompat.unicode(curpath)
+    def _onCurrentRepoChanged(self, curpath: str):
         self._console.setCurrentRepoRoot(curpath or None)
         self.reporegistry.setActiveTabRepo(curpath)
         if curpath:
@@ -985,7 +983,7 @@ class Workbench(QMainWindow):
         from tortoisehg.hgqt.hginit import InitDialog
         path = self.currentRepoRootPath() or '.'
         dlg = InitDialog(self.ui, path, self)
-        if dlg.exec_() == 0:
+        if dlg.exec() == 0:
             self.openRepo(dlg.destination(), False)
 
     @pyqtSlot()
@@ -1007,9 +1005,7 @@ class Workbench(QMainWindow):
         return dlg
 
     @pyqtSlot(str, str)
-    def _openClonedRepo(self, root, sourceroot):
-        root = pycompat.unicode(root)
-        sourceroot = pycompat.unicode(sourceroot)
+    def _openClonedRepo(self, root: str, sourceroot: str):
         self.reporegistry.addClonedRepo(root, sourceroot)
         self.showRepo(root)
 
@@ -1037,7 +1033,7 @@ class Workbench(QMainWindow):
         from tortoisehg.hgqt.about import AboutDialog
         ad = AboutDialog(self)
         ad.finished.connect(ad.deleteLater)
-        ad.exec_()
+        ad.exec()
 
     def onHelp(self, *args):
         """ Display online help """
@@ -1217,7 +1213,7 @@ class Workbench(QMainWindow):
         sd = SettingsDialog(configrepo=False, focus=focus,
                             parent=self,
                             root=hglib.fromunicode(self.currentRepoRootPath()))
-        sd.exec_()
+        sd.exec()
 
     @pyqtSlot()
     def _editCustomToolsSettings(self):
@@ -1227,4 +1223,4 @@ class Workbench(QMainWindow):
     def _openShortcutSettingsDialog(self):
         dlg = shortcutsettings.ShortcutSettingsDialog(
             self._actionregistry, self)
-        dlg.exec_()
+        dlg.exec()
