@@ -6,9 +6,8 @@
 # GNU General Public License version 2 or any later version.
 
 import os
-import sys
 
-from mercurial import hg, node, error, pycompat, scmutil
+from mercurial import hg, error, pycompat, scmutil
 from tortoisehg.util import paths, debugthg, hglib
 
 if hglib.TYPE_CHECKING:
@@ -41,12 +40,12 @@ try:
     from win32api import GetTickCount  # pytype: disable=import-error
     CACHE_TIMEOUT = 5000
     try:
-        hkey = OpenKey(HKEY_CURRENT_USER, r"Software\TortoiseHg")
-        enabled = QueryValueEx(hkey, 'EnableOverlays')[0] in ('1', 'True')
-        localonly = QueryValueEx(hkey, 'LocalDisksOnly')[0] in ('1', 'True')
-        incs = QueryValueEx(hkey, 'IncludePath')[0]
-        excs = QueryValueEx(hkey, 'ExcludePath')[0]
-        debugging = QueryValueEx(hkey, 'OverlayDebug')[0] in ('1', 'True')
+        with OpenKey(HKEY_CURRENT_USER, r"Software\TortoiseHg") as hkey:
+            enabled = QueryValueEx(hkey, 'EnableOverlays')[0] in ('1', 'True')
+            localonly = QueryValueEx(hkey, 'LocalDisksOnly')[0] in ('1', 'True')
+            incs = QueryValueEx(hkey, 'IncludePath')[0]
+            excs = QueryValueEx(hkey, 'ExcludePath')[0]
+            debugging = QueryValueEx(hkey, 'OverlayDebug')[0] in ('1', 'True')
         for p in incs.split(';'):
             path = p.strip()
             if path:
@@ -55,7 +54,7 @@ try:
             path = p.strip()
             if path:
                 excludepaths.append(path)
-    except EnvironmentError:
+    except OSError:
         pass
 except (AttributeError, ImportError):    # AttributeError for winreg.* on Unix
     from time import time as GetTickCount
