@@ -5,27 +5,27 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import print_function
+
 
 debugging = ''
 try:
     from mercurial.windows import winreg
     try:
         # pytype: disable=module-attr
-        hkey = winreg.OpenKey(winreg.HKEY_CURRENT_USER,
-                           r"Software\TortoiseHg", 0,
-                           winreg.KEY_ALL_ACCESS)
-        val = winreg.QueryValueEx(hkey, 'OverlayDebug')[0]
-        if val in ('1', 'True'):
-            debugging += 'O'
-        val = winreg.QueryValueEx(hkey, 'ContextMenuDebug')[0]
+        with winreg.OpenKey(winreg.HKEY_CURRENT_USER,
+                            r"Software\TortoiseHg", 0,
+                            winreg.KEY_ALL_ACCESS) as hkey:
+            val = winreg.QueryValueEx(hkey, 'OverlayDebug')[0]
+            if val in ('1', 'True'):
+                debugging += 'O'
+            val = winreg.QueryValueEx(hkey, 'ContextMenuDebug')[0]
         # pytype: enable=module-attr
 
         if val in ('1', 'True'):
             debugging += 'M'
         if debugging:
             import win32traceutil  # pytype: disable=import-error
-    except EnvironmentError:
+    except OSError:
         pass
 except (AttributeError, ImportError):    # AttributeError for winreg.* on Unix
     import os
