@@ -26,16 +26,15 @@ if os.name == 'nt':
         for key in (r"Software\GNU\GnuPG", r"Software\Wow6432Node\GNU\GnuPG"):
             try:
                 # pytype: disable=module-attr
-                hkey = winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE, key)
-                pfx = winreg.QueryValueEx(hkey, 'Install Directory')[0]
-                # pytype: enable=module-attr
+                with winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE, key) as hkey:
+                    pfx = winreg.QueryValueEx(hkey, 'Install Directory')[0]
+                    # pytype: enable=module-attr
+
                 for dirPath, dirNames, fileNames in os.walk(pfx):
                     for f in fileNames:
                         if f == 'gpg.exe':
                             path.append(os.path.join(dirPath, f))
-            except WindowsError:  # pytype: disable=name-error
-                pass
-            except EnvironmentError:
+            except OSError:
                 pass
 
         return path
