@@ -11,10 +11,14 @@ import ssl
 from mercurial import encoding, error, extensions, subrepo, util
 from mercurial import dispatch as dispatchmod
 
-from tortoisehg.util import hgversion
+from tortoisehg.util import (
+    hgversion,
+    version,
+)
 from tortoisehg.util.i18n import agettext as _
 
 testedwith = hgversion.testedwith
+getversion = version.version_bytes
 
 # exception handling different from _runcatch()
 def _dispatch(orig, req):
