@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import glob
 import io
@@ -15,6 +15,13 @@ import shlex
 import sys
 import time
 
+from typing import (
+    cast,
+    Iterable,
+    List,
+    Union,
+)
+
 from hgext import mq as mqmod
 from mercurial import (
     cmdutil,
@@ -65,12 +72,9 @@ if TYPE_CHECKING:
         Any,
         Callable,
         Dict,
-        Iterable,
-        List,
         Optional,
         Text,
         Tuple,
-        Union,
         overload,
     )
     from mercurial import (
@@ -102,9 +106,9 @@ tokenizerevspec = revsetlang.tokenize
 userrcpath = rcutil.userrcpath
 
 # TODO: use unicode version globally
-def _(message, context=''):
+def _(message: str, context: str = '') -> bytes:
     return _gettext(message, context).encode('utf-8')
-def ngettext(singular, plural, n):
+def ngettext(singular: str, plural: str, n: int) -> bytes:
     return _ngettext(singular, plural, n).encode('utf-8')
 
 if TYPE_CHECKING:
@@ -136,6 +140,9 @@ def tounicode(s):
         pass
     return s.decode(_fallbackencoding, 'replace')
 
+def to_unicode_list(seq: Iterable[Union[bytes, str]]) -> List[str]:
+    return cast(List[str], pycompat.maplist(tounicode, seq))
+
 if TYPE_CHECKING:
     @overload
     def fromunicode(s, errors='strict'):
@@ -157,7 +164,7 @@ def fromunicode(s, errors='strict'):
     """
     if s is None:
         return None
-    s = pycompat.unicode(s)  # s can be QtCore.QString
+
     for enc in (_encoding, _fallbackencoding):
         try:
             l = s.encode(enc)
@@ -219,14 +226,9 @@ def fromutf(s):
 
 getcwdb = encoding.getcwd
 
-if pycompat.ispy3:
-    def isbasestring(x):
-        return isinstance(x, str)
-    getcwdu = os.getcwd
-else:
-    def isbasestring(x):
-        return isinstance(x, basestring)  # pytype: disable=name-error
-    getcwdu = os.getcwdu  # pytype: disable=module-attr
+def isbasestring(x):
+    return isinstance(x, str)
+getcwdu = os.getcwd
 
 def activebookmark(repo):
     # type: (...) -> bytes
@@ -441,8 +443,6 @@ def allextensions():
     exts.update(enabledexts)
     exts.pop('configitems')   # tortoisehg.util.configitems
     if hasattr(sys, "frozen"):
-        if 'hgsubversion' not in exts:
-            exts['hgsubversion'] = _('hgsubversion packaged with thg')
         if 'hggit' not in exts:
             exts['hggit'] = _('hggit packaged with thg')
         if 'evolve' not in exts:
@@ -453,11 +453,6 @@ def allextensions():
     exts.pop('mercurial_extension_utils', None)  # Part of keyring extension
     exts.pop('hooklib', None)  # Internal, but also needs [hooks] setup
 
-    # The core git extension requires pygit2, which doesn't support py2, so no
-    # sense in advertising it.
-    if not pycompat.ispy3:
-        exts.pop('git', None)
-
     return exts
 
 def validateextensions(enabledexts):
@@ -532,7 +527,8 @@ def canonpaths(list):
             cwdu = cwd.upper()
             if fu.startswith(cwdu):
                 canonpats.append(
-                    pathutil.canonpath(root, cwd, f[len(cwd + os.sep):]))
+                    pathutil.canonpath(root, cwd, f[len(cwd + pycompat.ossep):])
+                )
             else:
                 # May already be canonical
                 canonpats.append(f)
@@ -896,6 +892,39 @@ def age(date):
 
     assert False, 'unreachable'
 
+def exception_str(e: Exception, show_hint: bool = False) -> str:
+    """Convert an exception object to a user consumable string.
+
+    If ``e`` is a core exception that implements ``mercurial.error.Hint``, the
+    optional hint message can be included by specifying ``show_hint=True``.
+    """
+
+    # Most (but not all) core API exceptions have ``__bytes__()`` to stringify
+    # the exception like BaseException, but in bytes instead of unicode.  Use
+    # that if available, and convert to unicode explicitly.  The ``__str()__``
+    # method on ``mercurial.error.Error`` calls ``__bytes__()``, but is only
+    # capable of decoding ascii.  The other core exceptions generally don't
+    # provide a ``__str()__`` override, which causes the raw bytes to be
+    # displayed (with the b"" prefix).
+    #
+    # Since there are multiple core exceptions that subclass builtin exceptions
+    # (instead of a single base core exception for everything else), assume the
+    # presence of ``__bytes__()`` means it's a core exception.
+    tobytes = getattr(e, "__bytes__", None)
+    if tobytes:
+        tostr = lambda: tounicode(tobytes())
+    else:
+        tostr = e.__str__
+
+    if show_hint and isinstance(e, error.Hint):
+        hint = getattr(e, "hint")
+
+        if hint:
+            return _gettext('%s (hint: %s)') % (tostr(), tounicode(hint))
+
+    return tostr()
+
+
 def configuredusername(ui):
     # type: (uimod.ui) -> Optional[bytes]
     # need to check the existence before calling ui.username(); otherwise it
@@ -955,7 +984,7 @@ def get_revision_desc(fctx, curpath=None):
     # type: (Any, Optional[bytes]) -> pycompat.unicode
     """return the revision description as a string"""
     author = tounicode(username(fctx.user()))
-    rev = fctx.linkrev()
+    rev = fctx.rev()
     # If the source path matches the current path, don't bother including it.
     if curpath and curpath == fctx.path():
         source = u''
@@ -1398,18 +1427,9 @@ def parsecmdline(cmdline, cwd):
     >>> glob.glob, os.path.expanduser, os.path.expandvars = origfuncs
     """
     _ = _gettext  # TODO: use unicode version globally
-    if pycompat.ispy3:
-        # shlex can't process bytes on Python 3
-        src = io.StringIO(cmdline)
-        lex = shlex.shlex(src, posix=True)
-        decode_token = pycompat.identity
-    else:
-        # shlex can't process non-ASCII unicode on Python 2
-        cmdline = cmdline.encode('utf-8')
-        src = util.bytesio(cmdline)
-        lex = shlex.shlex(src, posix=True)  # pytype: disable=wrong-arg-types
-        def decode_token(e):
-            return e.decode('utf-8')  # pytype: disable=attribute-error
+    # shlex can't process bytes on Python 3
+    src = io.StringIO(cmdline)
+    lex = shlex.shlex(src, posix=True)
     lex.whitespace_split = True
     lex.commenters = ''
     args = []
@@ -1423,7 +1443,7 @@ def parsecmdline(cmdline, cwd):
             raise ValueError(_('command parse error: %s') % err)
         if e == lex.eof:
             return args
-        e = decode_token(e)  # type: pycompat.unicode
+
         if q not in lex.quotes or q in lex.escapedquotes:
             e = os.path.expandvars(e)  # $var or "$var"
         if q not in lex.quotes:
@@ -1447,3 +1467,12 @@ def createsnewhead(ctx, branchheads=None):
     return branchheads and not any(
         p.node() in branchheads and p.branch() == branch for p in ctx.parents()
     )
+
+
+def dirstate_changing_files(repo: "localrepo.localrepository"):
+    try:
+        changing_files = repo.dirstate.changing_files
+    except AttributeError:
+        # hg<6.4 (3550e4a88ccd)
+        return util.nullcontextmanager()
+    return changing_files(repo)
