@@ -25,7 +25,7 @@ try:
 except ImportError:
     pass
 
-testedwith = b'5.9 6.0 6.1 6.2 6.3 6.4'
+testedwith = b'5.9 6.0 6.1 6.2 6.3 6.4 6.5 6.6'
 
 def _splitversion(v: bytes) -> Optional[List[bytes]]:
     """Extract (major, minor) version components as bytes, or None"""
