@@ -5,26 +5,23 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import gettext
 import locale
 import os
+from typing import (
+    Dict,
+    List,
+    Optional,
+)
 
 from mercurial import pycompat
 
 from . import paths
 
-if getattr(pycompat, 'TYPE_CHECKING', False):
-    from typing import (
-        Dict,
-        List,
-        Optional,
-        Text,
-    )
-
 _localeenvs = ('LANGUAGE', 'LC_ALL', 'LC_MESSAGES', 'LANG')
-def _defaultlanguage():
+def _defaultlanguage() -> Optional[str]:
     if os.name != 'nt' or any(e in os.environ for e in _localeenvs):
         return  # honor posix-style env var
 
@@ -42,13 +39,7 @@ def _defaultlanguage():
     except (ImportError, AttributeError, KeyError):
         pass
 
-# to be set later; don't assign these functions directly since they could
-# already be imported by name.
-_ugettext = None
-_ungettext = None
-
-def setlanguage(lang=None):
-    # type: (Optional[Text]) -> None
+def setlanguage(lang: Optional[str] = None) -> None:
     """Change translation catalog to the specified language"""
     global t, language
     if not lang:
@@ -58,19 +49,11 @@ def setlanguage(lang=None):
         opts['languages'] = (lang,)
     t = gettext.translation('tortoisehg', paths.get_locale_path(),
                             fallback=True, **opts)
-    global _ugettext, _ungettext
-    try:
-        _ugettext = t.ugettext  # pytype: disable=attribute-error
-        _ungettext = t.ungettext  # pytype: disable=attribute-error
-    except AttributeError:
-        _ugettext = t.gettext
-        _ungettext = t.ngettext
+    language = lang if lang else locale.getdefaultlocale(_localeenvs)[0]
 
-    language = lang or locale.getdefaultlocale(_localeenvs)[0]  # type: Optional[Text]
 setlanguage()
 
-def availablelanguages():
-    # type: () -> List[str]
+def availablelanguages() -> List[str]:
     """List up language code of which message catalog is available"""
     basedir = paths.get_locale_path()
     def mopath(lang):
@@ -82,21 +65,18 @@ def availablelanguages():
     langs.append('en')  # means null translation
     return sorted(langs)
 
-def _(message, context=''):
-    # type: (Text, Text) -> pycompat.unicode
+def _(message: str, context: str = '') -> str:
     if context:
         sep = '\004'
-        tmsg = _ugettext(context + sep + message)
+        tmsg = t.gettext(context + sep + message)
         if sep not in tmsg:
             return tmsg
-    return _ugettext(message)
+    return t.gettext(message)
 
-def ngettext(singular, plural, n):
-    # type: (Text, Text, int) -> pycompat.unicode
-    return _ungettext(singular, plural, n)
+def ngettext(singular: str, plural: str, n: int) -> str:
+    return t.ngettext(singular, plural, n)
 
-def agettext(message, context=''):
-    # type: (Text, Text) -> bytes
+def agettext(message: str, context: str = '') -> bytes:
     """Translate message and convert to local encoding
     such as 'ascii' before being returned.
 
@@ -111,6 +91,5 @@ def agettext(message, context=''):
         return pycompat.sysbytes(message)
 
 class keepgettext(object):
-    def _(self, message, context=''):
-        # type: (Text, Text) -> Dict[Text, Text]
+    def _(self, message: str, context: str = '') -> Dict[str, str]:
         return {'id': message, 'str': _(message, context)}
