@@ -10,9 +10,14 @@ from mercurial import error, patch, commands, extensions, context, node
 from mercurial.utils import (
     stringutil,
 )
-from tortoisehg.util import hgversion
+from tortoisehg.util import (
+    hglib,
+    hgversion,
+    version,
+)
 
 testedwith = hgversion.testedwith
+getversion = version.version_bytes
 
 def partialcommit(orig, ui, repo, *pats, **opts):
     patchfilename = opts.get('partials', None)
@@ -38,14 +43,11 @@ def partialcommit(orig, ui, repo, *pats, **opts):
         if hasattr(repo, '_filestore'):
             store.close()
             del repo._filestore
-            wlock = repo.wlock()
-            try:
+            with repo.wlock(), hglib.dirstate_changing_files(repo):
                 # mark partially committed files for 'needing lookup' in
                 # the dirstate.  The next status call will find them as M
                 for f in store.keys:
                     repo.dirstate.set_possibly_dirty(f)
-            finally:
-                wlock.release()
         return ret
     finally:
         if patchfilename:
