@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import print_function
+
 
 import os
 import binascii
@@ -16,7 +16,6 @@ from mercurial import (
     node,
     patch,
     phases,
-    pycompat,
     util,
 )
 
@@ -249,7 +248,7 @@ class patchctx(object):
             files[self._parseErrorFileName] = []
             self._parseerror = e
             if 'THGDEBUG' in os.environ:
-                print(e)
+                print(hglib.exception_str(e))
         finally:
             pf.close()
         return files
