@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import, print_function
+
 
 import os
 import shlex
@@ -169,14 +169,8 @@ if os.name == 'nt':
 
     def is_unc_path(path):
         # type: (bytes) -> bool
-        # splitdrive() on py2 didn't get UNC support until 2.7.8 in 2014, which
-        # means it may not be available on CentOS 7, for example.
-        if pycompat.ispy3:
-            unc, rest = os.path.splitdrive(path)
-            return len(unc) > 2
-        else:
-            unc, rest = os.path.splitunc(path)  # pytype: disable=module-attr
-            return bool(unc)
+        unc, rest = os.path.splitdrive(path)
+        return len(unc) > 2
 
     def is_on_fixed_drive(path):
         # type: (bytes) -> bool
