@@ -39,14 +39,16 @@ import time
 from mercurial import (
     error,
     scmutil,
-    pycompat,
-    util,
 )
 
-from tortoisehg.util import hgversion
+from tortoisehg.util import (
+    hgversion,
+    version,
+)
 from tortoisehg.util.i18n import agettext as _
 
 testedwith = hgversion.testedwith
+getversion = version.version_bytes
 
 class _labeledstr(bytes):
     r"""
