@@ -8,7 +8,7 @@
 '''update TortoiseHg status cache'''
 
 from mercurial import hg
-from tortoisehg.util import paths, shlib
+from tortoisehg.util import hglib, paths, shlib
 import os
 
 def cachefilepath(repo):
@@ -17,23 +17,23 @@ def cachefilepath(repo):
 def run(_ui, *pats, **opts):
 
     if opts.get('all'):
-        roots = []
-        base = os.getcwd()
+        roots = set()
+        base: bytes = hglib.getcwdb()
         for f in os.listdir(base):
-            r = paths.find_root(os.path.join(base, f))
+            r = paths.find_root_bytes(os.path.join(base, f))
             if r is not None:
-                roots.append(r)
+                roots.add(r)
         for r in roots:
-            _ui.note("%s\n" % r)
+            _ui.note(b"%s\n" % r)
             shlib.update_thgstatus(_ui, r, wait=False)
             shlib.shell_notify([r])
         return
 
-    root = paths.find_root()
+    root = paths.find_root_bytes()
     if opts.get('repository'):
         root = opts.get('repository')
     if root is None:
-        _ui.status("no repository\n")
+        _ui.status(b"no repository\n")
         return
 
     repo = hg.repository(_ui, root)
@@ -49,9 +49,9 @@ def run(_ui, *pats, **opts):
         try:
             with open(cachefilepath(repo), 'rb') as f:
                 for e in f:
-                    _ui.status("%s %s\n" % (e[0], e[1:-1]))
+                    _ui.status(b"%s %s\n" % (e[0:1], e[1:-1]))
         except IOError:
-            _ui.status("*no status*\n")
+            _ui.status(b"*no status*\n")
         return
 
     wait = opts.get('delay') is not None
@@ -59,4 +59,4 @@ def run(_ui, *pats, **opts):
 
     if opts.get('notify'):
         shlib.shell_notify(opts.get('notify'))
-    _ui.note("thgstatus updated\n")
+    _ui.note(b"thgstatus updated\n")
