@@ -6,7 +6,7 @@
 # GNU General Public License version 2 or any later version.
 
 
-from __future__ import absolute_import
+
 
 from mercurial import (
     pycompat,
@@ -32,6 +32,10 @@ if pycompat.TYPE_CHECKING:
         wconfig,
     )
 
+    from ..hgqt.qtcore import (
+        Qt,
+    )
+
     # Tuple of the executable path (if found), list of `.diffargs` and
     # list of `.diff3args` for a diff tool.
     DiffTool = Tuple[Optional[bytes], List[bytes], List[bytes]]
@@ -46,6 +50,11 @@ if pycompat.TYPE_CHECKING:
 
     IniConfig = TypeVar('IniConfig', wconfig._wconfig, config_mod.config)
 
+    try:
+        Qt_ItemFlags = Qt.ItemFlag
+    except ImportError:
+        Qt_ItemFlags = Qt.ItemFlags
+
     # The contexts returned from ``localrepository.__getitem()__``, including
     # regular ``HgContext``, as well as ``patchctx.patchctx`` for MQ related
     # objects.
