@@ -5,7 +5,7 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2 or any later version.
 
-from __future__ import absolute_import
+
 
 import os
 
@@ -16,6 +16,7 @@ from mercurial import (
     hg,
     pycompat,
     ui as uimod,
+    util,
 )
 
 from typing import (
@@ -25,6 +26,7 @@ from typing import (
 )
 
 
+@util.cachefunc
 def liveversion() -> Tuple[Text, Text]:
     'Attempt to read the version from the live repository'
     utilpath = os.path.dirname(os.path.realpath(__file__))
@@ -41,7 +43,11 @@ def liveversion() -> Tuple[Text, Text]:
     # prevent loading additional extensions
     for k, _v in u.configitems(b'extensions'):
         u.setconfig(b'extensions', k, b'!')
-    repo = hg.repository(u, path=pycompat.fsencode(thgpath))
+
+    with u.configoverride(
+        {(b'experimental', b'evolution.createmarkers'): True}, b'thg_version'
+    ):
+        repo = hg.repository(u, path=pycompat.fsencode(thgpath))
 
     u.pushbuffer()
     commands.identify(u, repo, id=True, tags=True, rev=b'.')
@@ -70,6 +76,9 @@ def version() -> Text:
     except ImportError:
         return 'unknown'
 
+def version_bytes() -> bytes:
+    return encoding.strtolocal(version())
+
 def package_version() -> Text:
     try:
         branch, version = liveversion()
