@@ -8,6 +8,12 @@
 import os
 import re
 
+from typing import (
+    Any,
+    Dict,
+    Iterator,
+)
+
 from mercurial import (
     config as config_mod,
     encoding,
@@ -24,10 +30,7 @@ if hglib.TYPE_CHECKING:
         Union,
     )
 
-if pycompat.ispy3:
-    import configparser
-else:
-    import ConfigParser as configparser  # pytype: disable=import-error
+import configparser
 
 try:
     from iniparse import INIConfig  # pytype: disable=import-error
@@ -36,16 +39,8 @@ except ImportError:
     _hasiniparse = False
 
 if _hasiniparse:
-    try:
-        # iniparse>=0.3.2
-        from iniparse import change_comment_syntax  # pytype: disable=import-error
-        change_comment_syntax(allow_rem=False)
-    except (ImportError, TypeError):
-        # TODO: yet need to care about iniparse<0.3.2 ??
-        from iniparse.ini import CommentLine  # pytype: disable=import-error
-        # Monkypatch this regex to prevent iniparse from considering
-        # 'rem' as a comment
-        CommentLine.regex = re.compile(r'^(?P<csep>[%;#])(?P<comment>.*)$')
+    from iniparse import change_comment_syntax  # pytype: disable=import-error
+    change_comment_syntax(allow_rem=False)
 
     # allow :suboption in <name>
     from iniparse.ini import OptionLine  # pytype: disable=import-error
@@ -65,32 +60,29 @@ def _unpackvalue(packed):
 
 class _wsortdict(object):
     """Wrapper for config.sortdict to record set/del operations"""
-    def __init__(self, dict):
-        self._dict = dict
+    def __init__(self, dict: Dict[bytes, Any]) -> None:
+        self._dict: Dict[bytes, Any] = dict
         self._log = []  # log of set/del operations
 
     # no need to wrap copy() since we don't keep trac of it.
 
-    def __contains__(self, key):
+    def __contains__(self, key: bytes) -> bool:
         return key in self._dict
 
-    def __getitem__(self, key):
+    def __getitem__(self, key: bytes):
         return self._dict[key]
 
-    def __setitem__(self, key, val):
+    def __setitem__(self, key: bytes, val) -> None:
         self._setdict(key, val)
         self._logset(key, _unpackvalue(val))
 
-    def _logset(self, key, val):
+    def _logset(self, key: bytes, val) -> None:
         """Record set operation to log; called also by _wconfig"""
-        if pycompat.ispy3:
-            key = pycompat.sysstr(key)
-            val = hglib.tounicode(val)
         def op(target):
-            target[key] = val
+            target[pycompat.sysstr(key)] = hglib.tounicode(val)
         self._log.append(op)
 
-    def _setdict(self, key, val):
+    def _setdict(self, key: bytes, val) -> None:
         if key not in self._dict:
             self._dict[key] = val  # append
             return
@@ -104,34 +96,32 @@ class _wsortdict(object):
         for k in list(self._dict):
             self._dict[k] = get(k)
 
-    def __iter__(self):
+    def __iter__(self) -> Iterator[bytes]:
         return iter(self._dict)
 
-    def __len__(self):
+    def __len__(self) -> int:
         return len(self._dict)
 
-    def update(self, src):
+    def update(self, src) -> None:
         if isinstance(src, _wsortdict):
             src = src._dict
         self._dict.update(src)
         self._logupdate(src)
 
-    def _logupdate(self, src):
+    def _logupdate(self, src) -> None:
         """Record update operation to log; called also by _wconfig"""
         for k in src:
             self._logset(k, _unpackvalue(src[k]))
 
-    def __delitem__(self, key):
+    def __delitem__(self, key: bytes) -> None:
         del self._dict[key]
         self._logdel(key)
 
-    def _logdel(self, key):
+    def _logdel(self, key: bytes) -> None:
         """Record del operation to log"""
-        if pycompat.ispy3:
-            key = pycompat.sysstr(key)
         def op(target):
             try:
-                del target[key]
+                del target[pycompat.sysstr(key)]
             except KeyError:  # in case somebody else deleted it
                 pass
         self._log.append(op)
@@ -139,7 +129,7 @@ class _wsortdict(object):
     def __getattr__(self, name):
         return getattr(self._dict, name)
 
-    def _replaylog(self, target):
+    def _replaylog(self, target) -> None:
         """Replay operations against the given target; called by _wconfig"""
         for op in self._log:
             op(target)
@@ -161,7 +151,7 @@ class _wconfig(object):
         # type: (Optional[Union[_wconfig, config_mod.config]]) -> None
         self._config = config_mod.config(data)
         self._readfiles = []  # list of read (path, fp, sections, remap)
-        self._sections = {}
+        self._sections: Dict[bytes, _wsortdict] = {}
 
         if isinstance(data, self.__class__):  # keep log
             self._readfiles.extend(data._readfiles)
@@ -172,10 +162,10 @@ class _wconfig(object):
     def copy(self):
         return self.__class__(self)
 
-    def __contains__(self, section):
+    def __contains__(self, section: bytes) -> bool:
         return section in self._config
 
-    def __getitem__(self, section):
+    def __getitem__(self, section: bytes) -> _wsortdict:
         try:
             return self._sections[section]
         except KeyError:
@@ -188,42 +178,54 @@ class _wconfig(object):
                 self._sections[section] = _wsortdict(self._config[section])
                 return self._sections[section]
             else:
-                return {}
+                return _wsortdict({})
 
     def __iter__(self):
         return iter(self._config)
 
-    def update(self, src):
+    def update(self, src) -> None:
         self._config.update(src)
         self._logupdates(src)
 
-    def _logupdates(self, src):
+    def _logupdates(self, src) -> None:
         for s in src:
             self[s]._logupdate(src[s])
 
-    def set(self, section, item, value, source=b''):
+    def set(
+        self,
+        section: bytes,
+        item: bytes,
+        value: bytes,
+        source: bytes=b''
+    ) -> None:
         assert isinstance(section, bytes), (section, item, value)
         assert isinstance(item, bytes), (section, item, value)
         assert isinstance(value, bytes), (section, item, value)
         self._setconfig(section, item, value, source)
         self[section]._logset(item, value)
 
-    def _setconfig(self, section, item, value, source):
+    def _setconfig(
+        self,
+        section: bytes,
+        item: bytes,
+        value: bytes,
+        source: bytes=b''
+    ) -> None:
         if item not in self._config[section]:
             # need to handle 'source'
             self._config.set(section, item, value, source)
         else:
             self[section][item] = _packvalue(self._config, value, source)
 
-    def remove(self, section, item):
+    def remove(self, section: bytes, item: bytes) -> None:
         del self[section][item]
         self[section]._logdel(item)
 
-    def read(self, path, fp=None, sections=None, remap=None):
+    def read(self, path: bytes, fp=None, sections=None, remap=None) -> None:
         self._config.read(path, fp, sections, remap)
         self._readfiles.append((path, fp, sections, remap))
 
-    def write(self, dest):
+    def write(self, dest) -> None:
         ini = self._readini()
         self._replaylogs(ini)
         dest.write(str(ini))
@@ -234,12 +236,6 @@ class _wconfig(object):
             raise NotImplementedError("wconfig does not support read() more "
                                       "than once")
 
-        def _filename(err):
-            if pycompat.ispy3:
-                return err.source
-            else:
-                return err.filename
-
         def newini(fp=None):
             try:
                 # TODO: optionxformvalue isn't used by INIConfig ?
@@ -247,13 +243,13 @@ class _wconfig(object):
             except configparser.MissingSectionHeaderError as err:
                 raise error.ParseError(
                     encoding.strtolocal(err.message.splitlines()[0]),
-                    encoding.strtolocal('%s:%d' % (_filename(err), err.lineno))
+                    encoding.strtolocal('%s:%d' % (err.source, err.lineno))
                 )
             except configparser.ParsingError as err:
                 if err.errors:
-                    loc = '%s:%d' % (_filename(err), err.errors[0][0])
+                    loc = '%s:%d' % (err.source, err.errors[0][0])
                 else:
-                    loc = _filename(err)
+                    loc = err.source
                 raise error.ParseError(
                     encoding.strtolocal(err.message.splitlines()[0]),
                     encoding.strtolocal(loc)
@@ -263,9 +259,7 @@ class _wconfig(object):
             return newini()
 
         def _read_new_ini(fp):
-            if pycompat.ispy3:
-                fp = pycompat.io.StringIO(hglib.tounicode(fp.read()))
-            return newini(fp)
+            return newini(pycompat.io.StringIO(hglib.tounicode(fp.read())))
 
         path, fp, sections, remap = self._readfiles[0]
 
@@ -295,9 +289,7 @@ class _wconfig(object):
                 return newns(section)
 
         for section, sortdict in self._sections.items():
-            if pycompat.ispy3:
-                section = pycompat.sysstr(section)
-            target = getsection(ini, section)
+            target = getsection(ini, pycompat.sysstr(section))
             sortdict._replaylog(target)
 
     def __getattr__(self, name):
@@ -314,22 +306,17 @@ def config(data=None):
     else:
         return config_mod.config(data)
 
-def readfile(path):
+def readfile(path: bytes):
     """Read the given file to return config object"""
     c = config()
     c.read(path)
     return c
 
-def writefile(config, path):
+def writefile(config, path: bytes) -> None:
     """Write the given config obj to the specified file"""
-    if pycompat.ispy3:
-        buf = pycompat.io.StringIO()
-        config.write(buf)
-        value = hglib.fromunicode(buf.getvalue())
-    else:
-        buf = util.bytesio()
-        config.write(buf)
-        value = buf.getvalue()
+    buf = pycompat.io.StringIO()
+    config.write(buf)
+    value = hglib.fromunicode(buf.getvalue())
     data = pycompat.oslinesep.join(value.splitlines() + [b''])
 
     if os.name == 'nt':
